<%@ Page Language="C#" AutoEventWireup="True" EnableViewState="True" %>

<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
	<title><%= LoginLabels.Title %></title>
</head>
<body>
	<p>This page is used for NTLM authentication. Upon successful authentication, you will be logged in and immediately redirected.</p>
	<p>To enable NTLM authentication, go to IIS Management Console and disable Anonymous Authentication while enabling Windows Authentication.</p>	
	<p style="font-weight:bold">NTLM Username: <asp:Label ID="_username" Text="None Found" runat="server"></asp:Label></p>
	<p style="color: red"><asp:Label ID="_message" runat="server"></asp:Label></p>	
    <script runat="server">
        OptionsService optionsService = IoC.Container.Resolve<OptionsService>();

        protected void Page_Load(object sender, EventArgs e)
        {
            PageHelper.RedirectToInstallationIfNoDatabaseFound();

			string username = User.Identity.Name;
			if (!string.IsNullOrEmpty(username))
			{
				_username.Text = username;
					
                AuthenticationHelper.Logout();
                AuthenticationResult authenticationResult = AuthenticationHelper.Authenticate(username, string.Empty, true);

				if (authenticationResult == AuthenticationResult.SuccessfullyAuthenticated)
				{
                    // redirect to URI we can access
                    IdentityContext identityContext = IoC.Container.Resolve<IdentityContext>();
                    if (identityContext.AuthenticatedUser.IsUserInAccount() == true)
                    {
                        GetAccountIncidentPermision();
                    }
                    else if (identityContext.AuthenticatedUser.IsUserInTeam() == true)
                    {
                        GetTeamIncidentPermision();
                    }
				}
				else
				{
					_message.Text = CommonLabels.ActiveDirectoryNtlmAuthenticationFailed.ToString();
				}
			}
        }

        private void GetTeamIncidentPermision()
        {
            AuthorizationService authorizationService = IoC.Container.Resolve<AuthorizationService>();
            Permission permission;
            if (authorizationService.CurrentPermissions.TryGetValue("/incidents", out permission) == true)
            {
                //Ako korisnik ima pravo na cijeli URI Tempalte onda neam smisla izlistavati sve URI toga oblika jer ocito ima pravo na temeljni URI , znaci taj URI TEmpalte Menu Item brisemo iz menija
                if (permission.Get == true)
                {
                    Response.Redirect(UrlHelper.GetUrl("/incidents?maxresults=100"));
                    return;
                }
            }

            IdentityContext identityContext = IoC.Container.Resolve<IdentityContext>();
            foreach (BusinessUnit team in identityContext.AuthenticatedUser.Data.BusinessUnits)
            {
                if (team.BusinessUnitType == BusinessUnitType.Team)
                {
                    string uriTmp = "/incidents/team/" + team.ID;
                    // uri must be in format "/incidents/team/{TeamID}/deleted"
                    if (authorizationService.CurrentPermissions.TryGetValue(uriTmp, out permission) == true)
                    {
                        if (permission.Get == true)
                        {
                            Response.Redirect(UrlHelper.GetUrl(uriTmp + "?maxresults=100"));
                        }
                    }
                    if (authorizationService.CurrentPermissions.TryGetValue("/incidents/team/{teamid}", out permission) == true)
                    {
                        if (permission.Get == true)
                        {
                            Response.Redirect(UrlHelper.GetUrl(uriTmp + "?maxresults=100"));
                        }
                    }
                }
            }
        }

        private void GetAccountIncidentPermision()
        {
            AuthorizationService authorizationService = IoC.Container.Resolve<AuthorizationService>();
            Permission permission;
            if (authorizationService.CurrentPermissions.TryGetValue("/incidentcontacts", out permission) == true)
            {
                //Ako korisnik ima pravo na cijeli URI Tempalte onda neam smisla izlistavati sve URI toga oblika jer ocito ima pravo na temeljni URI , znaci taj URI TEmpalte Menu Item brisemo iz menija
                if (permission.Get == true)
                {
                    Response.Redirect(UrlHelper.GetUrl("/incidentcontacts?maxresults=100"));
                }
            }

            IdentityContext identityContext = IoC.Container.Resolve<IdentityContext>();
            foreach (BusinessUnit account in identityContext.AuthenticatedUser.Data.BusinessUnits)
            {
                if (account.BusinessUnitType == BusinessUnitType.Account)
                {
                    string uriTmp = "/incidentcontacts/account/" + account.ID;
                    // uri must be in format "/incidents/team/{TeamID}/deleted"
                    if (authorizationService.CurrentPermissions.TryGetValue(uriTmp, out permission) == true)
                    {
                        if (permission.Get == true)
                        {
                            Response.Redirect(UrlHelper.GetUrl(uriTmp + "?maxresults=100"));
                        }
                    }
                    if (authorizationService.CurrentPermissions.TryGetValue("/incidentcontacts/account/{accountid}", out permission) == true)
                    {
                        if (permission.Get == true)
                        {
                            Response.Redirect(UrlHelper.GetUrl(uriTmp + "?maxresults=100"));
                        }
                    }
                }
            }

            // no global or account incident URIs with permission to read, resolve to reading own incidents
            Response.Redirect(UrlHelper.GetUrl("/incidentcontacts/contact/iperson/" + identityContext.AuthenticatedUser.ID.ToString() + "?maxresults=100"));
        }
    </script>
</body>
</html>
