<%@ Page language="C#" %>

<script runat="server">
    protected void Page_Load(object sender, EventArgs e)
    {
        if (Request.UserAgent == "Polar Help Desk Scheduler Service")
        {
            try
            {
                IdentityContext identityContext = IoC.Container.Resolve<IdentityContext>();
                identityContext.AuthenticateAsSystemUser();

                Scheduler scheduler = (Scheduler)IoC.Container.Resolve(typeof(Scheduler));
                scheduler.ExecuteScheduledTasks();

                identityContext.Logout();
            }
            catch (Exception ex)
            {
                StringBuilder strBuilder = new StringBuilder();

                strBuilder.Append("Error occured during scheduler request.\n");
                strBuilder.Append("Error message: ");
                strBuilder.Append(ex.Message);
                strBuilder.Append("\n");
                strBuilder.Append("Error source: ");
                strBuilder.Append(ex.Source);
                strBuilder.Append("\n");
                strBuilder.Append("Stack trace: ");
                strBuilder.Append(ex.StackTrace);
                if (ex.InnerException != null)
                {
                    strBuilder.Append("\n");
                    strBuilder.Append("Inner exception information:\n");
                    strBuilder.Append("Error message: ");
                    strBuilder.Append(ex.InnerException.Message);
                    strBuilder.Append("\n");
                    strBuilder.Append("Error source: ");
                    strBuilder.Append(ex.InnerException.Source);
                    strBuilder.Append("\n");
                    strBuilder.Append("Stack trace: ");
                    strBuilder.Append(ex.InnerException.StackTrace);
                }

                Response.Write(strBuilder.ToString());
                Response.StatusCode = Convert.ToInt32(HttpStatusCode.InternalServerError);
                Response.End();
            }
        }
    }
</script>

