var SkypeStyle = function (countOfClassesAvailable) {
    this.countOfClasses = countOfClassesAvailable;
    this.classNumberIncrementor = 0;
    this.classAssociationList = [];
    
    this.getClassName = function (userName, appendPosition) {
        var classNumber = 0;
        
        if (this.classAssociationList[userName]) {
            classNumber = this.classAssociationList[userName];
        } else {
            this.classNumberIncrementor = (this.classNumberIncrementor % this.countOfClasses) + 1;
            classNumber = this.classNumberIncrementor;
            this.classAssociationList[userName] = classNumber;  
        }
        
        return "chatMessageHeader_" + classNumber + "_" + appendPosition;
    }
    
    return this;
}


/**********************************************************/
var ChatRoomApp = function(containerElement, sessionManager) { 
    this.initialize(containerElement, sessionManager);
}

ChatRoomApp.prototype.initialize = function(containerElement, sessionManager) {

    this.skypeStyle = new SkypeStyle(5);
    this.inputTextArea = $$('.inputTextArea', containerElement);
    
    this.chatMessageTemplate = $$('.chatMessageTemplatePlaceholder > .chatMessage', containerElement);
    this.chatContents = $$('.chatContents', containerElement);
    this.chatContentScroller = new DivScroller(this.chatContents);
    this.chatStatus = $$('.chatStatus p', containerElement);
    
    $(this.inputTextArea).focus( delegate(this, function(e) { 
                                    e.target.select(); this.safeDeleteTextArea(); 
                                 }));
                                 
    $('.sendMessageButton', containerElement).click(delegate(this, function(e) { 
                                                        this.notifyIfServerCannotAcceptMessages();
                                                        this.handleSendMessage(); 
                                                        e.preventDefault();
                                                    }));
                                        
    
    $(this.inputTextArea).keypress(delegate(this, this.handleKeyPress));
                  
    this.userName = 'some user'; 
    this.sessionId = '';
    this.connectedSessionId = ''; 
    this.serverCanAcceptMessages = false;
    this.serverMessageAcceptanceNotification = null;
   
    sessionManager.registerServerEventListener(this, delegate(this, this.handleIncomingMessages));
};

ChatRoomApp.prototype.safeDeleteTextArea = function ()
{
    if (this.getInputText() == 'Type here and hit ctrl+enter to send a message')
    {
        this.setInputText('');
    }
}

ChatRoomApp.prototype.handleKeyPress = function(e) {
    if(e.keyCode) {
        if (e.keyCode == 16 || e.keyCode == 17 || e.keyCode == 18) //skip alt, ctrl and similar keys
            return true; 
            
        if ((e.keyCode == 13 || e.keyCode == 10) && e.ctrlKey) { //send on ctrl+enter
            this.handleSendMessage();
            e.preventDefault();
        }
    }
    
    if (this.getInputText().length == 0) {
        setTimeout(delegate(this, function() {
                      if (this.getInputText().length != 0)
                          this.notifyIfServerCannotAcceptMessages(); 
                   }), 130);
    }
}

ChatRoomApp.prototype.notifyIfServerCannotAcceptMessages = function()
{
    if (!this.serverCanAcceptMessages && this.serverMessageAcceptanceNotification)
    {
        var msg = this.serverMessageAcceptanceNotification;
        this.appendNewMessage(msg.UserName, msg.Message);
    }
}

ChatRoomApp.prototype.handleIncomingMessages = function(pollServerResult) 
{
    if (pollServerResult.Status)
    {
        this.setStatus(pollServerResult.Status);
        this.serverMessageAcceptanceNotification = pollServerResult.ServerMessageAcceptanceNotification;
        this.serverCanAcceptMessages = pollServerResult.ServerCanAcceptMessages;

    }
    else if (pollServerResult.Message)
    {
        this.appendNewMessage(pollServerResult.UserName, pollServerResult.Message);
    }
}

ChatRoomApp.prototype.setStatus = function(statusDescription) 
{
    $(this.chatStatus).text(statusDescription);
}

ChatRoomApp.prototype.getConnectedSessionId = function() 
{
    return this.connectedSessionId;
}

ChatRoomApp.prototype.setChatRoomInfo = function(userName, sessionId, connectedSessionId) 
{
    this.userName = userName;
    this.sessionId = sessionId;
    this.connectedSessionId = connectedSessionId;
}

ChatRoomApp.prototype.getInputText = function() 
{
    return this.inputTextArea.value;
}

ChatRoomApp.prototype.setInputText = function(text) {
    this.inputTextArea.value = text;
};

ChatRoomApp.prototype.createNewMessageNode = function(name, message) {
    var result = this.chatMessageTemplate.cloneNode(true);
    var userElement = $$('#chatMessageUser', result); 
    var messageElement =  $$('.chatMessageContent', result); 
    
    userElement.innerHTML = encodeHtml(name) + ":";
    messageElement.innerHTML = this.processMessageText(message);
    
    var userName = userElement.innerHTML;
    $('#chatMessageUser', result).attr('class', this.skypeStyle.getClassName(userName, "Left"));
    $('#chatMessageDateTime', result).attr('class', this.skypeStyle.getClassName(userName, "Right"));
    
    return result;
};

ChatRoomApp.prototype.processMessageText = function(message) {
    var urlRegexp = /(ftp|http|https):\/\/(\w+:{0,1}\w*@)?(\S+)(:[0-9]+)?(\/|\/([\w#!:.?+=&%@!\-\/]))?/gi;	
    
    var tempMessage = encodeHtml(message);
    tempMessage = tempMessage.replace(urlRegexp,
                                      function(url) {
                                          return '<a href="' + url + '" target="_blank">' + url + '</a>';
                                      });
    tempMessage = tempMessage.replace(/\r\n/g,"<br />").replace(/\n/g,"<br />").replace(/\r/g,"<br />")
    return tempMessage;
};

ChatRoomApp.prototype.appendNewMessage = function(name, message, forceChatContentScroll) {
    var newMessageNode = this.createNewMessageNode(name, message);
    this.chatContentScroller.doScrollCorrectingAction(forceChatContentScroll,
        delegate(this, function() { 
            this.chatContents.appendChild(newMessageNode);
        }));
};

ChatRoomApp.prototype.handleSendMessage = function() {
    var messageText = this.getInputText();
    if (!String.isNullOrBlank(messageText) && !String.isNullOrBlank(this.sessionId) &&
             !(messageText == 'Type here and hit ctrl+enter to send a message'))
    {
        this.sendMessageToServer(); 
        this.appendNewMessage(this.userName, messageText, true);
        this.setInputText('');        
    }  
};

ChatRoomApp.prototype.sendMessageToServer = function() 
{
    $.postJSON(ServerUrls.SendMessage, 
        
        { originatingSessionId: this.sessionId,
          targetSessionId: this.connectedSessionId, 
          message: this.getInputText() },
        
        delegate(this, function(sendMessageResult) 
        {
            for(var i = 0; i < sendMessageResult.length; i++)
            {
                this.handleIncomingMessages(sendMessageResult[i]);
            }        
        }));
};

/**********************************************************/

var UserSessionManager = function() {
    this.chatRoomListener = null;
    this.chatRoom = null;
    this.sessionId = '';
    this.intervalId_callPollServer = null;
};

UserSessionManager.prototype.registerServerEventListener = function(chatRoom, listener) {
    this.chatRoomListener = listener;
    this.chatRoom = chatRoom;
    chatRoom.setStatus("Support is offline");
    
    this.login();
};

UserSessionManager.prototype.login = function() 
{                                   
    $.postJSON(ServerUrls.EnterChatRoom,
        delegate(this, function(serverResult) 
        {
            if (this.intervalId_callPollServer)
                clearInterval(this.intervalId_callPollServer);
        
            if (serverResult == null || serverResult.length == 0 || serverResult[0].ConnectedSessionId == null)
            {
                setTimeout(delegate(this, this.login), 5000);  
                return;          
            }
            
            serverResult.dispatch([
                objectIs('LoginResult'), delegate(this, function(loginResult) 
                                         {
                                            this.sessionId = loginResult.SessionId;
                                            this.chatRoom.setChatRoomInfo(
                                                loginResult.UserSessionName,
                                                loginResult.SessionId,
                                                loginResult.ConnectedSessionId);
                                            
                                            this.intervalId_callPollServer = setInterval( delegate(this, this.pollServer), 3000);
                                         }),
                                         
                objectIs('StatusUpdate'), delegate(this, function(statusUpdate) 
                                          {
                                            this.chatRoomListener(statusUpdate);
                                          })
            ]);
        }));	
}

UserSessionManager.prototype.pollServer = function() {
    if (!String.isNullOrBlank(this.sessionId)) {
        $.postJSON(ServerUrls.PollMessage,
            { sessionId: this.sessionId },

            delegate(this, function(pollServerResult) {
                var badPoolServerResult = false;
                
                for(var i = 0; i < pollServerResult.length; i++) {
                    this.chatRoomListener(pollServerResult[i]);
                    if (pollServerResult[i].ServerCanAcceptMessages == false)
                        badPoolServerResult = true;   
                }
                
                if (badPoolServerResult == true || pollServerReult.length == 0 || pollServerReult.length == null )
                    this.login();          
            }));
    }
};

/**********************************************************/

var SupporterSessionManager = function() {
    this.tabContainer = new Ext.TabPanel($$('.activeChatsContainer'));
    
    this.chatRoomListeners = [];
    this.chatRooms = [];
    this.sessionId = '';
    this.userName = '';
    
    this.timeoutId_login = null;
    this.intervalId_pollServer = null;

    $('.activeSupportersBlock').show();
    $('.noChatsExplanation').show();
    $('.offlineExplanation').hide();
    $('.activeSupporters').show();
    
    visualModifyForwardToIncident('new');
    
    this.login();
};

SupporterSessionManager.prototype.login = function() {
    $.postJSON(ServerUrls.EnterSupporterRoom,
        delegate(this, function(serverResult) {
            if (serverResult == null || serverResult.length == 0)
            {
                this.timeoutId_login = setTimeout(delegate(this, this.login), 5000);  
                return;          
            }
            
            serverResult.dispatch(
                objectIs('LoginResult'), delegate(this, function(loginResult) 
                                         {
                                            this.sessionId = loginResult.SessionId;
                                            this.userName = loginResult.UserSessionName;
                                            this.intervalId_pollServer = setInterval(delegate(this, this.pollServer), 3000);                                          
                                         })
            );
    }));
};

SupporterSessionManager.prototype.pollServer = function() 
{
    if (!String.isNullOrBlank(this.sessionId)) {
        $.postJSON(ServerUrls.PollMessage,
            { sessionId: this.sessionId },
            delegate(this, function(pollServerResult)
            {
                $('.activeSupportersList').empty();
                this.dispatchReceivedMessages(pollServerResult);
            }));
    }
};

SupporterSessionManager.prototype.dispatchReceivedMessages = function(pollServerResult)
{
    pollServerResult.dispatch([
        objectIs('ChatMessage'), delegate(this, function(message) 
                                 {
                                    this.processMessage(message);
                                 }),
        
        objectIs('StatusUpdate'), delegate(this, function(statusUpdate) 
                                  {
                                      if (statusUpdate.OriginatingSessionId == 'BROADCAST')
                                          $('.globalStatus').text(statusUpdate.Status);
                                  }),
                                  
        objectIs('LoggedSupporterInfo'), delegate(this, function(supporterInfo)
                                         {
                                            var activeSupporterListItem = '<li>' + supporterInfo.SupporterName + '(' + supporterInfo.EndUserCount + ')' + '</li>';
                                            $('.activeSupportersList').append(activeSupporterListItem);                                                     
                                         }),
        
        all, delegate(this, function(obj)
             {
                this.chatRooms.dispatch(delegate(this, function(chatRoom)
                                        {
                                            return obj.OriginatingSessionId && 
                                                (obj.OriginatingSessionId == 'BROADCAST' ||
                                                 chatRoom.getConnectedSessionId() == obj.OriginatingSessionId);
                                        }),
                                        
                                        delegate(this, function(chatRoom, index)
                                        {
                                            this.chatRoomListeners[index](obj)
                                        }));
             })
    ]);
}

SupporterSessionManager.prototype.onCloseTabItem = function (tabItem) {
    if (tabItem.tabPanel.getCount() == 0) {
        visualModifyForwardToIncident('new');
    }
}

SupporterSessionManager.prototype.processMessage = function(message) {
    var foundRoom = false;
    var foundTab = false;
    var foundRoomObj = null;
    var chatRoomHtmlElement;
    var tabPanelItem;
    var tabPanelIndex;
    var chatRoom;
    
    this.triggerBrowserWindowBlinking();
    $('.noChatsExplanation').hide();
    
    for (var i = 0; i < this.chatRooms.length; i++) {
        if (this.chatRooms[i].connectedSessionId == message.OriginatingSessionId) {
            foundRoomObj = this.chatRooms[i];
            foundRoom = true;
            break;
        }
    }
    
    if (!foundRoom) {
        chatRoomHtmlElement = $$('.chatRoomTemplatePlaceholder > div').cloneNode(true);
        chatRoomHtmlElement.id = Ext.id();
        $('.activeChatsContainer').append(chatRoomHtmlElement)
        tabPanelItem = this.tabContainer.addTab(chatRoomHtmlElement.id, message.UserName, null, true);
        tabPanelIndex = this.tabContainer.getCount() - 1;
        
        chatRoom = new ChatRoomApp(chatRoomHtmlElement, this);
        chatRoom.setChatRoomInfo(this.userName, this.sessionId, message.OriginatingSessionId);
        chatRoom.setStatus('Talking to ' + message.UserName);
        tabPanelItem.associatedChatRoomAppObject = chatRoom;
        
    } else {
    
        for (var i = 0; i < this.tabContainer.getCount(); i++) {
            if (this.tabContainer.getTab(i).associatedChatRoomAppObject == foundRoomObj) {
                tabPanelItem = this.tabContainer.getTab(i);
                tabPanelIndex = i;
                foundTab = true;
                break;
            }
        }
        
        if (!foundTab) {
            chatRoomHtmlElement = $$('.chatRoomTemplatePlaceholder > div').cloneNode(true);
            chatRoomHtmlElement.id = Ext.id();
            $('.activeChatsContainer').append(chatRoomHtmlElement)
            tabPanelItem = this.tabContainer.addTab(chatRoomHtmlElement.id, message.UserName, null, true);	
            tabPanelIndex = this.tabContainer.getCount() - 1;
            
            foundRoomObj.initialize(chatRoomHtmlElement, this);
            foundRoomObj.setChatRoomInfo(this.userName, this.sessionId, message.OriginatingSessionId);
            foundRoomObj.setStatus('Talking to ' + message.UserName);			
            tabPanelItem.associatedChatRoomAppObject = foundRoomObj;			
        }
    }
    
    if (this.tabContainer.getCount() == 1) {
        visualModifyForwardToIncident('forward');
        this.tabContainer.getTab(0).activate();
    }
        
    if (tabPanelItem) {
        tabPanelItem.on('close', delegate(this, function() {
                                    if (this.tabContainer.getCount() == 0)
                                        $('.noChatsExplanation').show();
                                 }));
        tabPanelItem.on('close', this.onCloseTabItem);
    }
        
    this.triggerChatPanelBlinking(tabPanelIndex);		
};

SupporterSessionManager.prototype.getChatRoom = function (connectedSessionId) {
    var foundRoomObj = null;
    
    for (var i = 0; i < this.chatRooms.length; i++) {
        if (this.chatRooms[i].connectedSessionId == connectedSessionId) {
            foundRoomObj = this.chatRooms[i];
            break;
        }
    }
    
    return foundRoomObj;
}

SupporterSessionManager.prototype.getTabPanelItemContainingChatRoom = function (chatRoomObj) {
    var tabPanelItem = null;
    
    for (var i = 0; i < this.tabContainer.getCount(); i++) {
        if (this.tabContainer.getTab(i).associatedChatRoomAppObject == chatRoomObj) {
            tabPanelItem = this.tabContainer.getTab(i);
        }
    }
    
    return tabPanelItem;
}

SupporterSessionManager.prototype.triggerChatPanelBlinking = function (tabPanelIndex) 
{
    var tabPanelItem = this.tabContainer.getTab(tabPanelIndex);
    var tabPanelDom = tabPanelItem.bodyEl.dom;
    var chatTabSelector = '.activeChatsContainer .x-tabs-strip .x-tabs-closable:nth(' + tabPanelIndex + ')';

    if (tabPanelItem.isActive() && window.isFocused)
        return;

    blink({ blinkCount: 5,
            blinkDelay: 650,
            locker: tabPanelItem,
            blinkOn: function() { $(chatTabSelector).addClass('tab-blink'); },            
            blinkOff: function() { $(chatTabSelector).removeClass('tab-blink'); },
            init: function(blinker) 
                  {
                    soundManager.play('newMessageAlert');
                    tabPanelItem.on('activate', blinker.cancelBlinking);
                    $(tabPanelDom).bind('click', blinker.cancelBlinking);
                    $(tabPanelDom).bind('keyPress', blinker.cancelBlinking);
                  },
            finalize: function(blinker) 
                      {
                          soundManager.stop('newMessageAlert');
                          tabPanelItem.un('activate', blinker.cancelBlinking);
                          $(tabPanelDom).unbind('click', blinker.cancelBlinking);
                          $(tabPanelDom).unbind('keyPress', blinker.cancelBlinking);
                      }
    });
}

SupporterSessionManager.prototype.triggerBrowserWindowBlinking = function() 
{
    if (!window.isFocused)
    {
        blink({ blinkCount: 5,
                blinkDelay: 650,
                locker: this,
                data: { originalTitle: document.title },
                blinkOn: function() { document.title = 'New message'; },            
                blinkOff: function(blinker) { document.title = blinker.data.originalTitle; },
                init: function(blinker) { $(window).one('focus', blinker.cancelBlinking); }
              });
    }
}

SupporterSessionManager.prototype.registerServerEventListener = function(chatRoom, listener) 
{
    if (!this.chatRooms.exists(chatRoom))
    {
        this.chatRoomListeners.push(listener);
        this.chatRooms.push(chatRoom);
    }
};

SupporterSessionManager.prototype.close = function() 
{
    if (this.intervalId_pollServer) 
        clearInterval(this.intervalId_pollServer);
    if (this.timeoutId_login) 
        clearTimeout(this.timeoutId_login);
    
    $('.activeChatsContainer').html('');
    $('.activeSupportersList').empty();
    $('.globalStatus').empty();
    $('.activeSupportersList').empty();
    $('.noChatsExplanation').hide(); 
    $('.offlineExplanation').show();  
    $('.activeSupporters').hide();
    
    visualModifyForwardToIncident('new');
};



/**********************************************************/

var InitSupporterRoom = function() {
    this.supporterSession = null;
    
    soundManager.url = 'WebChat/soundmanager2.swf';
    soundManager.createMovie();
    soundManager.onload = function() {
      soundManager.createSound('newMessageAlert','WebChat/newMessageAlert.mp3');
    }
    
    visualModifyForwardToIncident('new');  
            
    $('#goOnline').click(delegate(this, function () {
        if ($('#goOnline').attr('class') == 'toolbarButtonDisabled')
            return false;
       
        if (this.supporterSession) {
            this.supporterSession.close();
            this.supporterSession = null;
        }
        this.supporterSession = new SupporterSessionManager();
        
        
        $('#goOnline').attr('class', 'toolbarButtonDisabled');
        $('img', '#goOnline').attr('src', 'images/16_startsupport_disabled.gif');
        
        $('#goOffline').attr('class', 'toolbarButtonEnabled');
        $('img', '#goOffline').attr('src', 'images/16_stopsupport.gif');
    }));
    

    $('#goOffline').click(delegate(this, function () {
        if ($('#goOffline').attr('class') == 'toolbarButtonDisabled')
            return false;
    
        if (this.supporterSession) {
            this.supporterSession.close();
            this.supporterSession = null;
        }
                
        $('#goOnline').attr('class', 'toolbarButtonEnabled');
        $('img', '#goOnline').attr('src', 'images/16_startsupport.gif');
        
        $('#goOffline').attr('class', 'toolbarButtonDisabled');
        $('img', '#goOffline').attr('src', 'images/16_stopsupport_disabled.gif');
    }));
    
    $('#goOnline').hover(
        function () {
            if ($(this).attr('class') == 'toolbarButtonEnabled') {
                $(this).attr('class', 'toolbarButtonEnabledHover');
            }
        }, 
        function () {
            if ($(this).attr('class') == 'toolbarButtonEnabledHover') {
                $(this).attr('class', 'toolbarButtonEnabled');
            }
        }
    );
    
    $('#goOffline').hover(
        function () {
            if ($(this).attr('class') == 'toolbarButtonEnabled') {
                $(this).attr('class', 'toolbarButtonEnabledHover');
            }
        }, 
        function () {
            if ($(this).attr('class') == 'toolbarButtonEnabledHover') {
                $(this).attr('class', 'toolbarButtonEnabled');
            }
        }
    );
    
    $('#forwardToIncident').click(delegate(this, function () {
        var tabContainer =null;
        var chatTranscriptID = null;
        var activeTab = null;
        var userSessionId = null;
        var supporterSessionId = null;
                
        if (this.supporterSession == null) {
            openIncidentEdit(null);
            return false;
        }
      
        tabContainer = this.supporterSession.tabContainer;
        
        if (tabContainer.getCount() == 0) {
            openIncidentEdit(null);
            return false;
        }
        
        activeTab = tabContainer.getActiveTab();
        userSessionId = activeTab.associatedChatRoomAppObject.connectedSessionId;
        supporterSessionId = activeTab.associatedChatRoomAppObject.sessionId;
        
        $.postJSON(ServerUrls.GetChatTranscriptId,
            { connectedSessionId: userSessionId, 
              sessionId: supporterSessionId },
            function (serverResult) {
                if (serverResult == null || serverResult.length == 0) {
                    return;          
                }
                
                openIncidentEdit(serverResult);
        });  
    }));
    
    $('#forwardToIncident').hover(
        function () { $(this).attr('class', 'toolbarButtonStatelessHover'); }, 
        function () { $(this).attr('class', 'toolbarButtonStateless'); }
    );
};

function openIncidentEdit(chatTranscriptID) {
    var urlAgumentedWithGET = ServerUrls.OpenIncident;
    
    if (chatTranscriptID) {
        urlAgumentedWithGET += "&ChatTranscriptID=" + chatTranscriptID;
    }
    
    window.open(urlAgumentedWithGET,'', 'status=yes,toolbar=no,resizable=yes,menubar=no,location=no,titlebar=yes,width=800,height=600');
}

function visualModifyForwardToIncident(state) {
    if (state === 'forward') {
        $('#forwardToIncidentPicture').attr('src', 'images/foward_to_incident_btn.gif');
        $('#forwardToIncidentText').text('Forward active chat to incident');
    } 
    else if (state === 'new') {
        $('#forwardToIncidentPicture').attr('src', 'images/foward_to_incident_btn_alternative.gif');
        $('#forwardToIncidentText').text('New incident');
    }
}

/**********************************************************/
var ServerUrls = {
    EnterChatRoom: getServerUrl('WebChat/EnterChatRoom.ashx'),
    EnterSupporterRoom: getServerUrl('WebChat/EnterSupporterRoom.ashx'),
    PollMessage: getServerUrl('WebChat/PollMessage.ashx'),
    SendMessage: getServerUrl('WebChat/SendMessage.ashx'),
    GetChatTranscriptId: getServerUrl('WebChat/GetChatTranscriptId.ashx'),
    OpenIncident: getServerUrl('Popups/IncidentPopup/IncidentEdit.aspx?PrimaryKey=0&TemplateID=1')
}

function getServerUrl(url) {
    return url;
}