/* =================================== UTILITIES ================================== */
function delegate(that, thatMethod) {
    return function() { return thatMethod.apply(that, arguments); }
}

function object(o) {
	function F() { }

	if (o) {
		F.prototype = o;
		return new F();
	} else {
		return {};
	}
}

function deleteAndNullify(o) {
    if (o) {
        delete o;
        o = null;
    }
}

function elemHasClass(elem, className)
{
    var classesInElem = $(elem).attr('class');
    if (classesInElem != undefined)
        return !(classesInElem.indexOf(className) == -1);
    else
        return false;
}

function get(symbol) {
  return function(target) {
    return target[symbol];
  }
}

function set(symbol, value) {
  return function(target) {
    return target[symbol] = value;
  }
}

function blink(blinkParams) {
    if (blinkParams.locker._blinkingFlag)
        return null;
    else
        blinkParams.locker._blinkingFlag = true;
        
    var blinker = {};
    blinker.blinkCount = blinkParams.blinkCount;
    blinker.blinkDelay = blinkParams.blinkDelay;
    blinker.blinkOff = blinkParams.blinkOff;
    blinker.blinkOn = blinkParams.blinkOn;
    blinker.locker = blinkParams.locker;
    blinker.data = blinkParams.data || {};
    blinker.done = false;
    
    blinker.cancelBlinking = function() {
        if (blinker.done)
            return;
        blinker.blinkCount = 0;
        blinker.blinkOff(blinker);
        performFinalization();
    }
    
    var toggleBlinkOn = function() {
        if (blinker.done)
            return;
        blinker.blinkOn(blinker);
        blinker.blinkCount--;
        
        if (blinker.blinkCount > 0)
            setTimeout(toggleBlinkOff, blinker.blinkDelay);
    }
    
    var toggleBlinkOff = function() {
        if (blinker.done)
            return;
        blinker.blinkOff(blinker);
        setTimeout(toggleBlinkOn, blinker.blinkDelay);
    }
    
    var performFinalization = function() {
        blinker.done = true;
        delete blinker.locker._blinkingFlag;
        if (blinkParams.finalize)
            blinkParams.finalize(blinker);
    }
    
    if (blinkParams.init)
        blinkParams.init(blinker);    
    toggleBlinkOn();
    return blinker;
}

blink.lockManager = {};

function addLoadEvent(func){
	var oldonload = window.onload;
	
	if (typeof window.onload != 'function') {
		window.onload = func;
	} else {
		window.onload = function() {
			oldonload();
			func();
		}
	}
}

function loggedExpression(value) {
	log.error(value);
	return value;
}

function encodeHtml(text) {
    var result = new String(text);
    result = result.replace(/&/g, "&amp;");
    result = result.replace(/</g, "&lt;");
    result = result.replace(/>/g, "&gt;");
    result = result.replace(/"/g, "&quot;"); 
	return result;
}

String.isString = function(obj) {
	return (typeof obj == "string" || obj instanceof String);
}

String.isNullOrBlank = function(obj) {
    return (!String.isString(obj)) || String.isBlank(obj);
}

String.isBlank = function(str) {
    return /^\s*$/.test(str);
}

Array.prototype.exists = function(obj) {
	for (var i = 0; i < this.length; i++)
	{
		if (this[i] == obj)
			return true;
	}
	return false;
}

Array.prototype.dispatch = function(a, b)
{
    var actions;
    
    if (!b)
        actions = a;
    else
        actions = [a, b];
        
    for (var i = 0; i < this.length; i++)
    {
        for (var j = 0; j < actions.length; j+=2)
        {
            var obj = this[i];
            if (actions[j](obj, i))
                actions[j+1](obj, i);
        }
    }
}

function all()
{
    return true;
}

function objectIs(objectType)
{
    return function(obj) 
    {
        return obj.ObjectType == objectType;
    }
}

var DivScroller = function(scrollContainer){
	this.bottomThreshold = 20;
    this.scrollContainer = scrollContainer;
    this._lastScrollPosition = 100000000;
}

//based on: http://radio.javaranch.com/pascarello/2006/08/17/1155837038219.html
DivScroller.prototype.doScrollCorrectingAction = function(forceScroll, action) {
    var _ref = this;
    var scrollDiv = this.scrollContainer;
    var currentHeight = 0;
    
    var _getElementHeight = function(){
      var intHt = 0;
      if(scrollDiv.style.pixelHeight)intHt = scrollDiv.style.pixelHeight;
      else intHt = scrollDiv.offsetHeight;
      return parseInt(intHt);
    }

    var _hasUserScrolled = function(){
      if(_ref._lastScrollPosition == scrollDiv.scrollTop || _ref._lastScrollPosition == null){
        return false;
      }
      return true;
    }

    if (scrollDiv.scrollHeight > 0) currentHeight = scrollDiv.scrollHeight;
    else if(scrollDiv.offsetHeight > 0) currentHeight = scrollDiv.offsetHeight;

	var _shouldScroll = (!_hasUserScrolled() || (currentHeight - scrollDiv.scrollTop - _getElementHeight() <= _ref.bottomThreshold) || forceScroll) ;
	action();
	
	if (_shouldScroll) {
		if (scrollDiv.scrollHeight > 0)
			currentHeight = scrollDiv.scrollHeight;
		else if(scrollDiv.offsetHeight > 0) 
			currentHeight = scrollDiv.offsetHeight;	
        scrollDiv.scrollTop = currentHeight;
        _ref._isUserActive = false	
	}

    _ref = null;
    scrollDiv = null;
}

/* ================================== JQUERY ENHACEMENTS ========================= */
function $$(a, c) {
	var result = jQuery(a, c).get();
	
	if (result.length == 1)
		return result[0];
	else
		return result;
}

jQuery.extend({
	postJSON: function( url, data, callback ) {
		return jQuery.post(url, data, callback, "json");
	},
	
	registerBehaviour: function(sheet) {
		jQuery(document).ready(function() {
							  		 for (selector in sheet) {
										jQuery(selector).each(function() { sheet[selector](this); });
									 }			
								});
	}
});

jQuery().ajaxError(function(request, settings, data, error) {
	log.error('Error occured: ' + error);
});

/* ======= OCTOPUS BORDERING IMPLEMENTATION (source: http://www.dragon-labs.com/articles/octopus/, our implementation is little modified to use cleaner markup ) ======= */
function initOctopus(element) {
	var classNames = ['octopus', 'squid', 'shark', 'swordfish'];
	var classTree = new Array(4);
	classTree[0]  = ["octopus-border", "north", "east", "south", "west", "ne", "se", "sw", "nw"];
	classTree[1]  = ["octopus-border", "faux", "north", "south"];
	classTree[2]  = ["octopus-border", "faux", "east", "west"];
	classTree[3]  = ["octopus-border", "north", "east", "west", "south"];
	
	var tempdivs = [];	
	for (var j=0; j<classNames.length; j++) {
		if (element.className.indexOf(classNames[j]) > -1) {
			jQuery(element).removeClass(classNames[j]).addClass('octopused');
			
			var innerElements = [];
			for(var b=element.childNodes.length - 1; b >= 0; b--) {
				innerElements[b] = element.removeChild(element.childNodes[b]);
			}
			
			var prevdiv = element;
			for (var a=0; a<classTree[j].length; a++) {
				tempdivs[a] = document.createElement('div');
				tempdivs[a].className = classTree[j][a];
				prevdiv.appendChild(tempdivs[a]);
				prevdiv = tempdivs[a];
			}
			prevdiv = document.createElement('div');
			prevdiv.className = 'octopus-inner';
			element.appendChild(prevdiv);
			for(var b=0; b<innerElements.length; b++) {
				prevdiv.appendChild(innerElements[b]);
			};
		}
	}				
}

jQuery.registerBehaviour({
	'div.octopus, div.squid, div.shark, div.swordfish': initOctopus
});

/* ============= IE TEXTAREA FIX (explanation: http://fplanque.net/2003/Articles/iecsstextarea/ ) =========== */
jQuery.registerBehaviour({
	'textarea.iefix': function(element) {
							var fieldset = document.createElement('fieldset');
							jQuery(fieldset).css({border: 'medium', padding: '0px', margin: '0px', width: '100%', height: '100%'});
							jQuery(element).wrap(fieldset).removeClass('iefix').addClass('iefixed');
						}
});

window.isFocused = false;

jQuery(window).focus(function() {
    this.isFocused = true;
});

jQuery(window).blur(function() {
    this.isFocused = false;
});


