/************************************************************/
/*****                  UpdateTableObjects              *****/
/************************************************************/

SET NUMERIC_ROUNDABORT OFF
GO
SET ANSI_PADDING, ANSI_WARNINGS, CONCAT_NULL_YIELDS_NULL, ARITHABORT, QUOTED_IDENTIFIER, ANSI_NULLS ON
GO
IF EXISTS (SELECT * FROM tempdb..sysobjects WHERE id=OBJECT_ID('tempdb..#tmpErrors')) DROP TABLE #tmpErrors
GO
CREATE TABLE #tmpErrors (Error int)
GO
SET XACT_ABORT ON
GO
SET TRANSACTION ISOLATION LEVEL SERIALIZABLE
GO
BEGIN TRANSACTION
GO
PRINT N'Creating [dbo].[EmailStatus]'
GO
CREATE TABLE [dbo].[EmailStatus]
(
[EmailStatusID] [bigint] NOT NULL IDENTITY(1, 1),
[EmailStatusName] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
[Active] [bit] NOT NULL CONSTRAINT [DF_EmailAction_Active] DEFAULT (1)
)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating primary key [PK_EmailAction] on [dbo].[EmailStatus]'
GO
ALTER TABLE [dbo].[EmailStatus] ADD CONSTRAINT [PK_EmailAction] PRIMARY KEY CLUSTERED  ([EmailStatusID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating [dbo].[EmailAccount]'
GO
CREATE TABLE [dbo].[EmailAccount]
(
[EmailAccountID] [bigint] NOT NULL IDENTITY(1, 1),
[EmailAccountName] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
[Server] [nvarchar] (200) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
[Port] [int] NOT NULL,
[Login] [nvarchar] (200) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
[Password] [nvarchar] (200) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
[IncidentTemplateID] [bigint] NOT NULL,
[Active] [bit] NOT NULL CONSTRAINT [DF_EmailAccount_Active] DEFAULT (1)
)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating primary key [PK_EmailAccount] on [dbo].[EmailAccount]'
GO
ALTER TABLE [dbo].[EmailAccount] ADD CONSTRAINT [PK_EmailAccount] PRIMARY KEY CLUSTERED  ([EmailAccountID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating [dbo].[Attachment_Email]'
GO
CREATE TABLE [dbo].[Attachment_Email]
(
[AttachmentID] [bigint] NOT NULL,
[EmailID] [bigint] NOT NULL
)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating primary key [PK_Attachment_Email] on [dbo].[Attachment_Email]'
GO
ALTER TABLE [dbo].[Attachment_Email] ADD CONSTRAINT [PK_Attachment_Email] PRIMARY KEY CLUSTERED  ([AttachmentID], [EmailID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Altering [dbo].[UserPreferenceType]'
GO
sp_rename N'[dbo].[UserPreferenceType].[UserPreferenceName]', N'UserPreferenceTypeName', 'COLUMN'
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating [dbo].[Email]'
GO
CREATE TABLE [dbo].[Email]
(
[EmailID] [bigint] NOT NULL IDENTITY(1, 1),
[MessageID] [nvarchar] (400) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
[FromEmail] [nvarchar] (500) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
[FromName] [nvarchar] (500) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
[Title] [nvarchar] (500) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
[ReceivedOn] [datetime] NOT NULL CONSTRAINT [DF_ProcessedEmail_ReceivedOn] DEFAULT (getdate()),
[ToEmail] [nchar] (500) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
[Body] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
[HTML] [bit] NOT NULL,
[XMLBlob] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL
)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating primary key [PK_Email] on [dbo].[Email]'
GO
ALTER TABLE [dbo].[Email] ADD CONSTRAINT [PK_Email] PRIMARY KEY CLUSTERED  ([EmailID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating index [IX_Email] on [dbo].[Email]'
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Email] ON [dbo].[Email] ([MessageID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating [dbo].[ReceivedEmail]'
GO
CREATE TABLE [dbo].[ReceivedEmail]
(
[ReceivedEmailID] [bigint] NOT NULL IDENTITY(1, 1),
[MessageID] [nvarchar] (400) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
[EmailStatusID] [bigint] NOT NULL,
[IncidentID] [bigint] NULL,
[ServiceUserID] [bigint] NULL,
[CreatedOn] [datetime] NOT NULL CONSTRAINT [DF_ReceivedEmail_CreatedOn] DEFAULT (getdate()),
[ModifiedOn] [datetime] NOT NULL CONSTRAINT [DF_ReceivedEmail_ModifiedOn] DEFAULT (getdate())
)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating primary key [PK_ReceivedEmail] on [dbo].[ReceivedEmail]'
GO
ALTER TABLE [dbo].[ReceivedEmail] ADD CONSTRAINT [PK_ReceivedEmail] PRIMARY KEY CLUSTERED  ([ReceivedEmailID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating index [IX_ReceivedEmail] on [dbo].[ReceivedEmail]'
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceivedEmail] ON [dbo].[ReceivedEmail] ([MessageID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Altering [dbo].[UserPreference]'
GO
ALTER TABLE [dbo].[UserPreference] ALTER COLUMN [UserPreferenceValue] [nvarchar] (500) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating [dbo].[BlockedEmail]'
GO
CREATE TABLE [dbo].[BlockedEmail]
(
[BlockedEmailID] [bigint] NOT NULL IDENTITY(1, 1),
[BlockedEmail] [nvarchar] (200) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL
)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating primary key [PK_BlockedEmail] on [dbo].[BlockedEmail]'
GO
ALTER TABLE [dbo].[BlockedEmail] ADD CONSTRAINT [PK_BlockedEmail] PRIMARY KEY CLUSTERED  ([BlockedEmailID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[ReceivedEmail]'
GO
ALTER TABLE [dbo].[ReceivedEmail] WITH NOCHECK ADD
CONSTRAINT [FK_ReceivedEmail_Email] FOREIGN KEY ([MessageID]) REFERENCES [dbo].[Email] ([MessageID]),
CONSTRAINT [FK_ReceivedEmail_Incident] FOREIGN KEY ([IncidentID]) REFERENCES [dbo].[Incident] ([IncidentID]),
CONSTRAINT [FK_ReceivedEmail_Users] FOREIGN KEY ([ServiceUserID]) REFERENCES [dbo].[Users] ([UserID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[Attachment_Email]'
GO
ALTER TABLE [dbo].[Attachment_Email] ADD
CONSTRAINT [FK_Attachment_Email_Attachment] FOREIGN KEY ([AttachmentID]) REFERENCES [dbo].[Attachment] ([AttachmentID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[EmailAccount]'
GO
ALTER TABLE [dbo].[EmailAccount] ADD
CONSTRAINT [FK_EmailAccount_IncidentTemplate] FOREIGN KEY ([IncidentTemplateID]) REFERENCES [dbo].[IncidentTemplate] ([IncidentTemplateID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[ReceivedEmail]'
GO
ALTER TABLE [dbo].[ReceivedEmail] ADD
CONSTRAINT [FK_ReceivedEmail_EmailStatus] FOREIGN KEY ([EmailStatusID]) REFERENCES [dbo].[EmailStatus] ([EmailStatusID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Disabling constraints on [dbo].[ReceivedEmail]'
GO
ALTER TABLE [dbo].[ReceivedEmail] NOCHECK CONSTRAINT
[FK_ReceivedEmail_Email],
[FK_ReceivedEmail_Incident],
[FK_ReceivedEmail_Users]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
IF EXISTS (SELECT * FROM #tmpErrors) ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT>0 BEGIN
PRINT 'The database updated succeeded'
COMMIT TRANSACTION
END
ELSE PRINT 'The database update failed'
GO
DROP TABLE #tmpErrors
GO

/************************************************************/
/*****                  UpdateDefaultValues             *****/
/************************************************************/


/************************************************************/
/*****                       Options                    *****/
/************************************************************/

UPDATE [dbo].[Options] SET [OptionValue]='800' WHERE [OptionID]=4

UPDATE [dbo].[Options] SET [OptionValue]='600' WHERE [OptionID]=5

INSERT INTO [dbo].[Options]([OptionName], [OptionValue]) VALUES ('IncomingEmailServer', '');

INSERT INTO [dbo].[Options]([OptionName], [OptionValue]) VALUES ('IncomingEmailServerPortNumber', '110');

INSERT INTO [dbo].[Options]([OptionName], [OptionValue]) VALUES ('IncomingEmailServerUserName', '');

INSERT INTO [dbo].[Options]([OptionName], [OptionValue]) VALUES ('IncomingEmailServerPassword', '');

INSERT INTO [dbo].[Options]([OptionName], [OptionValue]) VALUES ('LeaveCopyOfMessagesOnServer', 'false');

INSERT INTO [dbo].[Options]([OptionName], [OptionValue]) VALUES ('RemoveCopyOfMessagesFromServerAfter', '0');

INSERT INTO [dbo].[Options]([OptionName], [OptionValue]) VALUES ('EmailAutomationMode', '0');

INSERT INTO [dbo].[Options]([OptionName], [OptionValue]) VALUES ('SaveAllEmails', 'true');

INSERT INTO [dbo].[Options]([OptionName], [OptionValue]) VALUES ('EnableRemoveCopyOfMessagesFromServerAfter', 'false');

/************************************************************/
/*****                   UserToNotify                   *****/
/************************************************************/
INSERT INTO [dbo].[UserToNotify] ([UserToNotifyName]) VALUES ('All Old Assigned Group Members')


/************************************************************/
/*****                 NotificationRule                 *****/
/************************************************************/

UPDATE [dbo].[NotificationRule] SET NotificationRuleName='Incident Group Reassagnied' WHERE NotificationRuleID=3

INSERT INTO [dbo].[NotificationRule] ([NotificationRuleName], [NotificationID]) VALUES ('Incident Incident Status Changed to In Progress', 1)

INSERT INTO [dbo].[NotificationRule] ([NotificationRuleName], [NotificationID]) VALUES ('Incident Incident Status Changed to Waiting', 1)

INSERT INTO [dbo].[NotificationRule] ([NotificationRuleName], [NotificationID]) VALUES ('Incident Incident Status Changed to Resolved', 1)

INSERT INTO [dbo].[NotificationRule] ([NotificationRuleName], [NotificationID]) VALUES ('Incident Incident Status Changed to Completed', 1)

INSERT INTO [dbo].[NotificationRule] ([NotificationRuleName], [NotificationID]) VALUES ('Incident Incident Status Changed to Closed', 1)

INSERT INTO [dbo].[NotificationRule] ([NotificationRuleName], [NotificationID]) VALUES ('Incident Updated', 1)

/************************************************************/
/*****                     EmailStatus 	                *****/
/************************************************************/

INSERT INTO [dbo].[EmailStatus] (EmailStatusName) VALUES ('On Hold')

INSERT INTO [dbo].[EmailStatus] (EmailStatusName) VALUES ('Converted To Incident')

INSERT INTO [dbo].[EmailStatus] (EmailStatusName) VALUES ('Cancelled')

INSERT INTO [dbo].[EmailStatus] (EmailStatusName) VALUES ('Blocked')

/************************************************************/
/*****                UserPreferenceType                *****/
/************************************************************/
INSERT INTO [dbo].[UserPreferenceType] (UserPreferenceTypeName) VALUES ('LastPageVisited')

/************************************************************/
/*****                  DatabaseVersion		        *****/
/************************************************************/

UPDATE [dbo].[DatabaseVersion] SET [VersionNumber]='1.6.0.0'
