/************************************************************/
/*****                  UpdateTableObjects              *****/
/************************************************************/

SET NUMERIC_ROUNDABORT OFF
GO
SET ANSI_PADDING, ANSI_WARNINGS, CONCAT_NULL_YIELDS_NULL, ARITHABORT, QUOTED_IDENTIFIER, ANSI_NULLS ON
GO
IF EXISTS (SELECT * FROM tempdb..sysobjects WHERE id=OBJECT_ID('tempdb..#tmpErrors')) DROP TABLE #tmpErrors
GO
CREATE TABLE #tmpErrors (Error int)
GO
SET XACT_ABORT ON
GO
SET TRANSACTION ISOLATION LEVEL SERIALIZABLE
GO
BEGIN TRANSACTION
GO
PRINT N'Creating [dbo].[Attachment_KnowledgeBaseItem]'
GO
CREATE TABLE [dbo].[Attachment_KnowledgeBaseItem]
(
[AttachmentID] [bigint] NOT NULL,
[KnowledgeBaseItemID] [bigint] NOT NULL
)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating primary key [PK_Attachment_KnowledgeBaseItem] on [dbo].[Attachment_KnowledgeBaseItem]'
GO
ALTER TABLE [dbo].[Attachment_KnowledgeBaseItem] ADD CONSTRAINT [PK_Attachment_KnowledgeBaseItem] PRIMARY KEY CLUSTERED  ([AttachmentID], [KnowledgeBaseItemID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating [dbo].[KnowledgeBaseItemStatus]'
GO
CREATE TABLE [dbo].[KnowledgeBaseItemStatus]
(
[KnowledgeBaseItemStatusID] [bigint] NOT NULL IDENTITY(1, 1),
[KnowledgeBaseItemStatusName] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
[Active] [bit] NOT NULL CONSTRAINT [DF_KnowledgeBaseItemStatusID_Active] DEFAULT (1)
)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating primary key [PK_KnowledgeBaseItemStatusID] on [dbo].[KnowledgeBaseItemStatus]'
GO
ALTER TABLE [dbo].[KnowledgeBaseItemStatus] ADD CONSTRAINT [PK_KnowledgeBaseItemStatusID] PRIMARY KEY CLUSTERED  ([KnowledgeBaseItemStatusID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating [dbo].[KnowledgeBaseItemHistory]'
GO
CREATE TABLE [dbo].[KnowledgeBaseItemHistory]
(
[KnowledgeBaseItemHistoryID] [bigint] NOT NULL IDENTITY(1, 1),
[KnowledgeBaseItemID] [bigint] NOT NULL,
[CreatedBy] [bigint] NOT NULL,
[Title] [nvarchar] (500) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
[Body] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
[KnowledgeBaseItemStatusID] [bigint] NOT NULL,
[KnowledgeBaseItemTypeID] [bigint] NOT NULL,
[KeyWords] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CreatedOn] [datetime] NOT NULL CONSTRAINT [DF_KnowledgeBaseItemHistory_CreatedOn] DEFAULT (getdate()),
[ModifiedOn] [datetime] NOT NULL CONSTRAINT [DF_KnowledgeBaseItemHistory_ModifiedOn] DEFAULT (getdate()),
[ParentKnowledgeBaseItemID] [bigint] NULL,
[Note] [nvarchar] (2000) COLLATE SQL_Latin1_General_CP1_CI_AS NULL
)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating primary key [PK_KnowledgeBaseItemHistory] on [dbo].[KnowledgeBaseItemHistory]'
GO
ALTER TABLE [dbo].[KnowledgeBaseItemHistory] ADD CONSTRAINT [PK_KnowledgeBaseItemHistory] PRIMARY KEY CLUSTERED  ([KnowledgeBaseItemHistoryID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating [dbo].[KnowledgeBaseItemType]'
GO
CREATE TABLE [dbo].[KnowledgeBaseItemType]
(
[KnowledgeBaseItemTypeID] [bigint] NOT NULL IDENTITY(1, 1),
[KnowledgeBaseItemTypeName] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
[Active] [bit] NOT NULL CONSTRAINT [DF_KnowledgeBaseItemType_Active] DEFAULT (1)
)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating primary key [PK_KnowledgeBaseItemType] on [dbo].[KnowledgeBaseItemType]'
GO
ALTER TABLE [dbo].[KnowledgeBaseItemType] ADD CONSTRAINT [PK_KnowledgeBaseItemType] PRIMARY KEY CLUSTERED  ([KnowledgeBaseItemTypeID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating [dbo].[KnowledgeBaseItem]'
GO
CREATE TABLE [dbo].[KnowledgeBaseItem]
(
[KnowledgeBaseItemID] [bigint] NOT NULL IDENTITY(1, 1),
[Title] [nvarchar] (500) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
[Body] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
[KnowledgeBaseItemStatusID] [bigint] NOT NULL,
[KnowledgeBaseItemTypeID] [bigint] NOT NULL,
[KeyWords] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[Note] [nvarchar] (2000) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CreatedBy] [bigint] NOT NULL,
[CreatedOn] [datetime] NOT NULL CONSTRAINT [DF_KnowledgeBaseItem_CreatedOn] DEFAULT (getdate()),
[ModifiedOn] [datetime] NOT NULL CONSTRAINT [DF_KnowledgeBaseItem_ModifiedOn] DEFAULT (getdate()),
[ParentKnowledgeBaseItemID] [bigint] NULL
)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating primary key [PK_KnowledgeBaseItem] on [dbo].[KnowledgeBaseItem]'
GO
ALTER TABLE [dbo].[KnowledgeBaseItem] ADD CONSTRAINT [PK_KnowledgeBaseItem] PRIMARY KEY CLUSTERED  ([KnowledgeBaseItemID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[KnowledgeBaseItem]'
GO
ALTER TABLE [dbo].[KnowledgeBaseItem] WITH NOCHECK ADD
CONSTRAINT [FK_KnowledgeBaseItem_KnowledgeBaseItem] FOREIGN KEY ([ParentKnowledgeBaseItemID]) REFERENCES [dbo].[KnowledgeBaseItem] ([KnowledgeBaseItemID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[KnowledgeBaseItemHistory]'
GO
ALTER TABLE [dbo].[KnowledgeBaseItemHistory] WITH NOCHECK ADD
CONSTRAINT [FK_KnowledgeBaseItemHistory_KnowledgeBaseItem1] FOREIGN KEY ([ParentKnowledgeBaseItemID]) REFERENCES [dbo].[KnowledgeBaseItem] ([KnowledgeBaseItemID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[Attachment_KnowledgeBaseItem]'
GO
ALTER TABLE [dbo].[Attachment_KnowledgeBaseItem] ADD
CONSTRAINT [FK_Attachment_KnowledgeBaseItem_Attachment] FOREIGN KEY ([AttachmentID]) REFERENCES [dbo].[Attachment] ([AttachmentID]),
CONSTRAINT [FK_Attachment_KnowledgeBaseItem_KnowledgeBaseItem] FOREIGN KEY ([KnowledgeBaseItemID]) REFERENCES [dbo].[KnowledgeBaseItem] ([KnowledgeBaseItemID]) ON DELETE CASCADE
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[KnowledgeBaseItemHistory]'
GO
ALTER TABLE [dbo].[KnowledgeBaseItemHistory] ADD
CONSTRAINT [FK_KnowledgeBaseItemHistory_KnowledgeBaseItem] FOREIGN KEY ([KnowledgeBaseItemID]) REFERENCES [dbo].[KnowledgeBaseItem] ([KnowledgeBaseItemID]) ON DELETE CASCADE,
CONSTRAINT [FK_KnowledgeBaseItemHistory_Users] FOREIGN KEY ([CreatedBy]) REFERENCES [dbo].[Users] ([UserID]),
CONSTRAINT [FK_KnowledgeBaseItemHistory_KnowledgeBaseItemStatusID] FOREIGN KEY ([KnowledgeBaseItemStatusID]) REFERENCES [dbo].[KnowledgeBaseItemStatus] ([KnowledgeBaseItemStatusID]),
CONSTRAINT [FK_KnowledgeBaseItemHistory_KnowledgeBaseItemType] FOREIGN KEY ([KnowledgeBaseItemTypeID]) REFERENCES [dbo].[KnowledgeBaseItemType] ([KnowledgeBaseItemTypeID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[KnowledgeBaseItem]'
GO
ALTER TABLE [dbo].[KnowledgeBaseItem] ADD
CONSTRAINT [FK_KnowledgeBaseItem_KnowledgeBaseItemStatusID] FOREIGN KEY ([KnowledgeBaseItemStatusID]) REFERENCES [dbo].[KnowledgeBaseItemStatus] ([KnowledgeBaseItemStatusID]),
CONSTRAINT [FK_KnowledgeBaseItem_KnowledgeBaseItemType] FOREIGN KEY ([KnowledgeBaseItemTypeID]) REFERENCES [dbo].[KnowledgeBaseItemType] ([KnowledgeBaseItemTypeID]),
CONSTRAINT [FK_KnowledgeBaseItem_Users] FOREIGN KEY ([CreatedBy]) REFERENCES [dbo].[Users] ([UserID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Disabling constraints on [dbo].[KnowledgeBaseItem]'
GO
ALTER TABLE [dbo].[KnowledgeBaseItem] NOCHECK CONSTRAINT
[FK_KnowledgeBaseItem_KnowledgeBaseItem]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Disabling constraints on [dbo].[KnowledgeBaseItemHistory]'
GO
ALTER TABLE [dbo].[KnowledgeBaseItemHistory] NOCHECK CONSTRAINT
[FK_KnowledgeBaseItemHistory_KnowledgeBaseItem1]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
IF EXISTS (SELECT * FROM #tmpErrors) ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT>0 BEGIN
PRINT 'The database updated succeeded'
COMMIT TRANSACTION
END
ELSE PRINT 'The database update failed'
GO
DROP TABLE #tmpErrors
GO

/************************************************************/
/*****            KnowledgeBaseItemStatus 	        *****/
/************************************************************/

INSERT INTO [dbo].[KnowledgeBaseItemStatus] (KnowledgeBaseItemStatusName) VALUES ('Draft')

INSERT INTO [dbo].[KnowledgeBaseItemStatus] (KnowledgeBaseItemStatusName) VALUES ('Approved')

INSERT INTO [dbo].[KnowledgeBaseItemStatus] (KnowledgeBaseItemStatusName) VALUES ('Unapproved')

/************************************************************/
/*****            KnowledgeBaseItemType 	        *****/
/************************************************************/

INSERT INTO [dbo].[KnowledgeBaseItemType] (KnowledgeBaseItemTypeName) VALUES ('Article')

INSERT INTO [dbo].[KnowledgeBaseItemType] (KnowledgeBaseItemTypeName) VALUES ('Folder')


/************************************************************/
/*****                  DatabaseVersion		        *****/
/************************************************************/

UPDATE [dbo].[DatabaseVersion] SET [VersionNumber]='1.6.0.2'

