SET NUMERIC_ROUNDABORT OFF
GO
SET ANSI_PADDING, ANSI_WARNINGS, CONCAT_NULL_YIELDS_NULL, ARITHABORT, QUOTED_IDENTIFIER, ANSI_NULLS ON
GO
IF EXISTS (SELECT * FROM tempdb..sysobjects WHERE id=OBJECT_ID('tempdb..#tmpErrors')) DROP TABLE #tmpErrors
GO
CREATE TABLE #tmpErrors (Error int)
GO
SET XACT_ABORT ON
GO
SET TRANSACTION ISOLATION LEVEL SERIALIZABLE
GO
BEGIN TRANSACTION
GO
PRINT N'Creating [dbo].[KnowledgeBaseItemRating]'
GO
CREATE TABLE [dbo].[KnowledgeBaseItemRating]
(
[KnowledgeBaseItemRatingID] [bigint] NOT NULL IDENTITY(1, 1),
[KnowledgeBaseItemID] [bigint] NOT NULL,
[Rate] [tinyint] NOT NULL,
[Comment] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
[CreatedBy] [bigint] NULL,
[CreatedOn] [datetime] NULL CONSTRAINT [DF_KnowledgeBaseItemRating_CreatedOn] DEFAULT (getdate())
)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating primary key [PK_KnowledgeBaseItemRating] on [dbo].[KnowledgeBaseItemRating]'
GO
ALTER TABLE [dbo].[KnowledgeBaseItemRating] ADD CONSTRAINT [PK_KnowledgeBaseItemRating] PRIMARY KEY CLUSTERED  ([KnowledgeBaseItemRatingID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating [dbo].[Image]'
GO
CREATE TABLE [dbo].[Image]
(
[ImageID] [bigint] NOT NULL IDENTITY(1, 1),
[ImageName] [nvarchar] (256) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
[Image] [image] NOT NULL,
[ImageSize] [int] NOT NULL,
[ImageType] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
[CreatedOn] [datetime] NOT NULL CONSTRAINT [DF_Image_CreatedOn] DEFAULT (getdate())
)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating primary key [PK_Image] on [dbo].[Image]'
GO
ALTER TABLE [dbo].[Image] ADD CONSTRAINT [PK_Image] PRIMARY KEY CLUSTERED  ([ImageID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating [dbo].[Group_KnowledgeBaseItem]'
GO
CREATE TABLE [dbo].[Group_KnowledgeBaseItem]
(
[GroupID] [bigint] NOT NULL,
[KnowledgeBaseItemID] [bigint] NOT NULL
)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating primary key [PK_Group_KnowledgeBaseItem] on [dbo].[Group_KnowledgeBaseItem]'
GO
ALTER TABLE [dbo].[Group_KnowledgeBaseItem] ADD CONSTRAINT [PK_Group_KnowledgeBaseItem] PRIMARY KEY CLUSTERED  ([GroupID], [KnowledgeBaseItemID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating [dbo].[Image_KnowledgeBaseItem]'
GO
CREATE TABLE [dbo].[Image_KnowledgeBaseItem]
(
[ImageID] [bigint] NOT NULL,
[KnowledgeBaseItemID] [bigint] NOT NULL
)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating primary key [PK_Table1_1] on [dbo].[Image_KnowledgeBaseItem]'
GO
ALTER TABLE [dbo].[Image_KnowledgeBaseItem] ADD CONSTRAINT [PK_Table1_1] PRIMARY KEY CLUSTERED  ([ImageID], [KnowledgeBaseItemID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Altering [dbo].[KnowledgeBaseItem]'
GO
ALTER TABLE [dbo].[KnowledgeBaseItem] ADD
[ChildrenCount] [int] NOT NULL CONSTRAINT [DF_KnowledgeBaseItem_ChilderenCount] DEFAULT (0),
[Viewed] [bigint] NOT NULL CONSTRAINT [DF_KnowledgeBaseItem_Viewed] DEFAULT (0),
[ExpiresOn] [datetime] NULL,
[ScheduledOn] [datetime] NULL,
[ReviewOn] [datetime] NULL
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Altering [dbo].[KnowledgeBaseItemHistory]'
GO
ALTER TABLE [dbo].[KnowledgeBaseItemHistory] ADD
[ChildrenCount] [int] NULL CONSTRAINT [DF_KnowledgeBaseItemHistory_ChildrenCount] DEFAULT (0),
[Viewed] [bigint] NOT NULL CONSTRAINT [DF_KnowledgeBaseItemHistory_Viewed] DEFAULT (0),
[ExpiresOn] [datetime] NULL,
[ScheduledOn] [datetime] NULL,
[ReviewOn] [datetime] NULL
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[KnowledgeBaseItemRating]'
GO
ALTER TABLE [dbo].[KnowledgeBaseItemRating] WITH NOCHECK ADD
CONSTRAINT [FK_KnowledgeBaseItemRating_Users] FOREIGN KEY ([CreatedBy]) REFERENCES [dbo].[Users] ([UserID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[Group_KnowledgeBaseItem]'
GO
ALTER TABLE [dbo].[Group_KnowledgeBaseItem] ADD
CONSTRAINT [FK_Group_KnowledgeBaseItem_Groups] FOREIGN KEY ([GroupID]) REFERENCES [dbo].[Groups] ([GroupID]) ON DELETE CASCADE,
CONSTRAINT [FK_Group_KnowledgeBaseItem_KnowledgeBaseItem] FOREIGN KEY ([KnowledgeBaseItemID]) REFERENCES [dbo].[KnowledgeBaseItem] ([KnowledgeBaseItemID]) ON DELETE CASCADE
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[Image_KnowledgeBaseItem]'
GO
ALTER TABLE [dbo].[Image_KnowledgeBaseItem] ADD
CONSTRAINT [FK_Image_KnowledgeBaseItem_Image] FOREIGN KEY ([ImageID]) REFERENCES [dbo].[Image] ([ImageID]) ON DELETE CASCADE,
CONSTRAINT [FK_Image_KnowledgeBaseItem_KnowledgeBaseItem] FOREIGN KEY ([KnowledgeBaseItemID]) REFERENCES [dbo].[KnowledgeBaseItem] ([KnowledgeBaseItemID]) ON DELETE CASCADE
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[KnowledgeBaseItemRating]'
GO
ALTER TABLE [dbo].[KnowledgeBaseItemRating] ADD
CONSTRAINT [FK_KnowledgeBaseItemRating_KnowledgeBaseItem] FOREIGN KEY ([KnowledgeBaseItemID]) REFERENCES [dbo].[KnowledgeBaseItem] ([KnowledgeBaseItemID]) ON DELETE CASCADE
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Disabling constraints on [dbo].[KnowledgeBaseItemRating]'
GO
ALTER TABLE [dbo].[KnowledgeBaseItemRating] NOCHECK CONSTRAINT
[FK_KnowledgeBaseItemRating_Users]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
IF EXISTS (SELECT * FROM #tmpErrors) ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT>0 BEGIN
PRINT 'The database updated succeeded'
COMMIT TRANSACTION
END
ELSE PRINT 'The database update failed'
GO
DROP TABLE #tmpErrors
GO

/************************************************************/
/*****                   Options                        *****/
/************************************************************/

INSERT INTO [dbo].[Options]([OptionName], [OptionValue]) VALUES ('PublicKnowledgeBase', 'true');

INSERT INTO [dbo].[Options]([OptionName], [OptionValue]) VALUES ('AllowKnowledgeBaseIndexing', 'true');

INSERT INTO [dbo].[Options]([OptionName], [OptionValue]) VALUES ('SearchResultsMode', '0');


/************************************************************/
/*****                    Items                        *****/
/************************************************************/
-- KnowledgeBase Desktop
INSERT INTO [dbo].[Item]([ItemName], [AllowCreate], [AllowRead], [AllowUpdate], [AllowDelete]) VALUES('Knowledge Base Desktop', 0, 1, 0, 0)

INSERT INTO [dbo].[Item]([ItemName], [AllowCreate], [AllowRead], [AllowUpdate], [AllowDelete], [ParentItemID]) VALUES('Editing', 0, 1, 0, 0, 53)

INSERT INTO [dbo].[Item]([ItemName], [AllowCreate], [AllowRead], [AllowUpdate], [AllowDelete], [ParentItemID]) VALUES('Administration', 0, 1, 0, 0, 53)

/************************************************************/
/*****                   Permissions                    *****/
/************************************************************/

INSERT INTO [dbo].[Permission]([RoleID], [ItemID], [PermissionCreate], [PermissionRead], [PermissionUpdate], [PermissionDelete]) VALUES(1, 53, 0, 1, 0, 0)

INSERT INTO [dbo].[Permission]([RoleID], [ItemID], [PermissionCreate], [PermissionRead], [PermissionUpdate], [PermissionDelete]) VALUES(1, 54, 0, 1, 0, 0)

INSERT INTO [dbo].[Permission]([RoleID], [ItemID], [PermissionCreate], [PermissionRead], [PermissionUpdate], [PermissionDelete]) VALUES(1, 55, 0, 1, 0, 0)

INSERT INTO [dbo].[Permission]([RoleID], [ItemID], [PermissionCreate], [PermissionRead], [PermissionUpdate], [PermissionDelete]) VALUES(2, 53, 0, 1, 0, 0)

INSERT INTO [dbo].[Permission]([RoleID], [ItemID], [PermissionCreate], [PermissionRead], [PermissionUpdate], [PermissionDelete]) VALUES(2, 54, 0, 1, 0, 0)

INSERT INTO [dbo].[Permission]([RoleID], [ItemID], [PermissionCreate], [PermissionRead], [PermissionUpdate], [PermissionDelete]) VALUES(2, 55, 0, 1, 0, 0)

INSERT INTO [dbo].[Permission]([RoleID], [ItemID], [PermissionCreate], [PermissionRead], [PermissionUpdate], [PermissionDelete]) VALUES(3, 53, 0, 1, 0, 0)

INSERT INTO [dbo].[Permission]([RoleID], [ItemID], [PermissionCreate], [PermissionRead], [PermissionUpdate], [PermissionDelete]) VALUES(3, 54, 0, 1, 0, 0)

INSERT INTO [dbo].[Permission]([RoleID], [ItemID], [PermissionCreate], [PermissionRead], [PermissionUpdate], [PermissionDelete]) VALUES(3, 55, 0, 0, 0, 0)

INSERT INTO [dbo].[Permission]([RoleID], [ItemID], [PermissionCreate], [PermissionRead], [PermissionUpdate], [PermissionDelete]) VALUES(4, 53, 0, 1, 0, 0)

INSERT INTO [dbo].[Permission]([RoleID], [ItemID], [PermissionCreate], [PermissionRead], [PermissionUpdate], [PermissionDelete]) VALUES(4, 54, 0, 0, 0, 0)

INSERT INTO [dbo].[Permission]([RoleID], [ItemID], [PermissionCreate], [PermissionRead], [PermissionUpdate], [PermissionDelete]) VALUES(4, 55, 0, 0, 0, 0)

/************************************************************/
/*****            KnowledgeBaseItemStatus	        *****/
/************************************************************/


INSERT INTO [dbo].[KnowledgeBaseItemStatus] (KnowledgeBaseItemStatusName) VALUES ('Withdrawn')


/************************************************************/
/*****               KnowledgeBaseItem        	        *****/
/************************************************************/

INSERT INTO [dbo].[KnowledgeBaseItem] (Title, Body, KnowledgeBaseItemStatusID, KnowledgeBaseItemTypeID, CreatedBy) VALUES ('Welcome to Knowledge Base', '<p><font face=Arial size=2>Use the &lsquo;Browse&rsquo; tab to browse for content or &lsquo;Search&rsquo; tab to search for content.</font></p>', 2, 2, 1)

/************************************************************/
/*****                  DatabaseVersion		        *****/
/************************************************************/

UPDATE [dbo].[DatabaseVersion] SET [VersionNumber]='4.0.0.0'
