SET NUMERIC_ROUNDABORT OFF
GO
SET ANSI_PADDING, ANSI_WARNINGS, CONCAT_NULL_YIELDS_NULL, ARITHABORT, QUOTED_IDENTIFIER, ANSI_NULLS ON
GO
IF EXISTS (SELECT * FROM tempdb..sysobjects WHERE id=OBJECT_ID('tempdb..#tmpErrors')) DROP TABLE #tmpErrors
GO
CREATE TABLE #tmpErrors (Error int)
GO
SET XACT_ABORT ON
GO
SET TRANSACTION ISOLATION LEVEL SERIALIZABLE
GO
BEGIN TRANSACTION
GO
PRINT N'Creating [dbo].[LanguageLabel]'
GO
CREATE TABLE [dbo].[LanguageLabel]
(
[LanguageLabelID] [bigint] NOT NULL IDENTITY(1, 1),
[LabelKey] [bigint] NOT NULL,
[LanguageID] [bigint] NOT NULL,
[LabelValue] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
[Description] [nvarchar] (2000) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CreatedOn] [datetime] NOT NULL CONSTRAINT [DF_LanguageLabel_CreatedOn] DEFAULT (getdate()),
[ModifiedOn] [datetime] NOT NULL CONSTRAINT [DF_LanguageLabel_ModifiedOn] DEFAULT (getdate())
)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating primary key [PK_LanguageData] on [dbo].[LanguageLabel]'
GO
ALTER TABLE [dbo].[LanguageLabel] ADD CONSTRAINT [PK_LanguageData] PRIMARY KEY CLUSTERED  ([LanguageLabelID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Altering [dbo].[BusinessUnit]'
GO
ALTER TABLE [dbo].[BusinessUnit] ADD
[LanguageID] [bigint] NULL CONSTRAINT [DF_BusinessUnit_LanguageID] DEFAULT (1)
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Altering [dbo].[Users]'
GO
ALTER TABLE [dbo].[Users] ADD
[LanguageID] [bigint] NULL CONSTRAINT [DF_Users_LanguageID] DEFAULT (1)
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating [dbo].[Languages]'
GO
CREATE TABLE [dbo].[Languages]
(
[LanguageID] [bigint] NOT NULL IDENTITY(1, 1),
[LanguageName] [nvarchar] (200) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
[LanguageTypeID] [bigint] NOT NULL,
[LanguageDescription] [nvarchar] (2000) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[LanguageCode] [nvarchar] (200) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[Active] [bit] NOT NULL CONSTRAINT [DF_Languages_Active] DEFAULT (1)
)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating primary key [PK_Languages] on [dbo].[Languages]'
GO
ALTER TABLE [dbo].[Languages] ADD CONSTRAINT [PK_Languages] PRIMARY KEY CLUSTERED  ([LanguageID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating [dbo].[LanguageType]'
GO
CREATE TABLE [dbo].[LanguageType]
(
[LanguageTypeID] [bigint] NOT NULL IDENTITY(1, 1),
[LanguageTypeName] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
[Active] [bit] NOT NULL CONSTRAINT [DF_LanguageType_Active] DEFAULT (1)
)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating primary key [PK_LanguageType] on [dbo].[LanguageType]'
GO
ALTER TABLE [dbo].[LanguageType] ADD CONSTRAINT [PK_LanguageType] PRIMARY KEY CLUSTERED  ([LanguageTypeID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Altering [dbo].[Email]'
GO
ALTER TABLE [dbo].[Email] ALTER COLUMN [ToEmail] [nvarchar] (500) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[BusinessUnit]'
GO
ALTER TABLE [dbo].[BusinessUnit] WITH NOCHECK ADD
CONSTRAINT [FK_BusinessUnit_Languages] FOREIGN KEY ([LanguageID]) REFERENCES [dbo].[Languages] ([LanguageID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[Users]'
GO
ALTER TABLE [dbo].[Users] WITH NOCHECK ADD
CONSTRAINT [FK_Users_Languages] FOREIGN KEY ([LanguageID]) REFERENCES [dbo].[Languages] ([LanguageID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[LanguageLabel]'
GO
ALTER TABLE [dbo].[LanguageLabel] ADD
CONSTRAINT [FK_LanguageData_Languages] FOREIGN KEY ([LanguageID]) REFERENCES [dbo].[Languages] ([LanguageID]) ON DELETE CASCADE
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[Languages]'
GO
ALTER TABLE [dbo].[Languages] ADD
CONSTRAINT [FK_Languages_LanguageType] FOREIGN KEY ([LanguageTypeID]) REFERENCES [dbo].[LanguageType] ([LanguageTypeID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Disabling constraints on [dbo].[BusinessUnit]'
GO
ALTER TABLE [dbo].[BusinessUnit] NOCHECK CONSTRAINT
[FK_BusinessUnit_Languages]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Disabling constraints on [dbo].[Users]'
GO
ALTER TABLE [dbo].[Users] NOCHECK CONSTRAINT
[FK_Users_Languages]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
IF EXISTS (SELECT * FROM #tmpErrors) ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT>0 BEGIN
PRINT 'The database updated succeeded'
COMMIT TRANSACTION
END
ELSE PRINT 'The database update failed'
GO
DROP TABLE #tmpErrors
GO


/************************************************************/
/*****                 LanguageType                     *****/
/************************************************************/

INSERT INTO [dbo].[LanguageType] ([LanguageTypeName]) VALUES ('PredefinedLanguage')

INSERT INTO [dbo].[LanguageType] ([LanguageTypeName]) VALUES ('CustomLanguage')

/************************************************************/
/*****                    Languages                     *****/
/************************************************************/

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Afrikaans', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Albanian', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Arabic (Saudi Arabia)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Arabic (Iraq)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Arabic (Egypt)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Arabic (Libya)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Arabic (Algeria)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Arabic (Morocco)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Arabic (Tunisia)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Arabic (Oman)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Arabic (Yemen)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Arabic (Syria)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Arabic (Jordan)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Arabic (Lebanon)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Arabic (Kuwait)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Arabic (UAE)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Arabic (Bahrain)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Arabic (Qatar)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Armenian', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Azeri (Latin)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Azeri (Cyrillic)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Basque', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Belarusian', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Bengali (India)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Bosnian (Latin)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Bulgarian', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Catalan', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Chinese (Taiwan)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Chinese (PRC)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Chinese (Hong Kong)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Chinese (Singapore)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Chinese (Macau)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Croatian', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Croatian (Bosnia and Herzegovina)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Czech', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Danish', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Divehi', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Dutch (Standard)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Dutch (Belgian)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('English (United States)', 1, 1)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('English (United Kingdom)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('English (Australian)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('English (Canadian)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('English (New Zealand)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('English (Ireland)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('English (South Africa)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('English (Jamaica)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('English (Caribbean)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('English (Belize)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('English (Trinidad)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('English (Zimbabwe)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('English (Philippines)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Estonian', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Faeroese', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Farsi', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Finnish', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('French (Standard)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('French (Belgian)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('French (Canadian)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('French (Swiss)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('French (Luxembourg)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('French (Monaco)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Georgian', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Galician', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('German (Standard)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('German (Swiss)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('German (Austrian)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('German (Luxembourg)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('German (Liechtenstein)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Greek', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Gujarati', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Hebrew', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Hindi', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Hungarian', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Icelandic', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Indonesian', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Italian (Standard)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Italian (Swiss)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Japanese', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Kannada', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Kazakh', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Konkani', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Korean', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Kyrgyz', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Latvian', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Lithuanian', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Macedonian', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Malay (Malaysia)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Malay (Brunei Darussalam)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Malayalam', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Maltese', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Maori', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Marathi', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Mongolian', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Norwegian (Bokmal)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Norwegian (Nynorsk)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Polish', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Portuguese (Brazilian)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Portuguese (Standard)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Punjabi', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Quechua (Bolivia)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Quechua (Ecuador)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Quechua (Peru)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Romanian', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Russian', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Sami (Inari)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Sami (Lule Norway)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Sami (Lule Sweden)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Sami (Northern Finland)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Sami (Northern Norway)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Sami (Northern Sweden)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Sami (Skolt)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Sami (Southern Norway)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Sami (Southern Sweden)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Sanskrit', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Serbian (Latin)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Serbian (Latin Bosnia and Herzegovina)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Serbian (Cyrillic)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Serbian (Cyrillic Bosnia and Herzegovina)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Slovak', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Slovenian', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Spanish (Traditional Sort)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Spanish (Mexican)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Spanish (Modern Sort)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Spanish (Guatemala)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Spanish (Costa Rica)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Spanish (Panama)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Spanish (Dominican Republic)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Spanish (Venezuela)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Spanish (Colombia)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Spanish (Peru)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Spanish (Argentina)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Spanish (Ecuador)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Spanish (Chile)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Spanish (Uruguay)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Spanish (Paraguay)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Spanish (Bolivia)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Spanish (El Salvador)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Spanish (Honduras)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Spanish (Nicaragua)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Spanish (Puerto Rico)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Swahili', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Swedish', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Swedish (Finland)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Syriac', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Tamil', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Tatar', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Telugu', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Thai', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Tswana', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Turkish', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Ukrainian', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Urdu', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Uzbek (Latin)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Uzbek (Cyrillic)', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Vietnamese', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Welsh', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Xhosa', 1, 0)

INSERT INTO [dbo].[Languages] ([LanguageName], [LanguageTypeID], [Active]) VALUES ('Zulu', 1, 0)


/************************************************************/
/*****                      Options	                *****/
/************************************************************/

INSERT INTO [dbo].[Options]([OptionName], [OptionValue]) VALUES ('DefaultLanguage', '40');

/************************************************************/
/*****                  DatabaseVersion		        *****/
/************************************************************/

UPDATE [dbo].[DatabaseVersion] SET [VersionNumber]='4.1.0.0'

