/* enable full text indexing */
EXEC sp_fulltext_database 'enable';
GO
/* delete permissions to avoid any potential problems */
DELETE FROM Permission;
/* delete user preferences to avoid any potential problems */
DELETE FROM UserPreference;
/* delete lables to avoid any potential problems */
DELETE FROM LanguageLabel;
/* remove duplicate emails */
UPDATE Users SET Email = UserName + '@' + UserName, ReceiveEmails = 0  WHERE (Email IN (SELECT Email FROM Users GROUP BY Email HAVING (COUNT(Email) > 1)));



SET NUMERIC_ROUNDABORT OFF
GO
SET ANSI_PADDING, ANSI_WARNINGS, CONCAT_NULL_YIELDS_NULL, ARITHABORT, QUOTED_IDENTIFIER, ANSI_NULLS ON
GO
IF EXISTS (SELECT * FROM tempdb..sysobjects WHERE id=OBJECT_ID('tempdb..#tmpErrors')) DROP TABLE #tmpErrors
GO
CREATE TABLE #tmpErrors (Error int)
GO
SET XACT_ABORT ON
GO
SET TRANSACTION ISOLATION LEVEL SERIALIZABLE
GO
BEGIN TRANSACTION
GO
PRINT N'Dropping foreign keys from [dbo].[Announcement]'
GO
ALTER TABLE [dbo].[Announcement] DROP
CONSTRAINT [FK_Announcement_Users]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Dropping foreign keys from [dbo].[Service]'
GO
ALTER TABLE [dbo].[Service] DROP
CONSTRAINT [FK_Service_Users]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Dropping foreign keys from [dbo].[User_Role]'
GO
ALTER TABLE [dbo].[User_Role] DROP
CONSTRAINT [FK_User_Role_Users]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Dropping foreign keys from [dbo].[UserPreference]'
GO
ALTER TABLE [dbo].[UserPreference] DROP
CONSTRAINT [FK_UserPreference_Users],
CONSTRAINT [FK_UserPreference_UserPreferenceType]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Dropping foreign keys from [dbo].[KnowledgeBaseItemRating]'
GO
ALTER TABLE [dbo].[KnowledgeBaseItemRating] DROP
CONSTRAINT [FK_KnowledgeBaseItemRating_Users]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Dropping foreign keys from [dbo].[Read_IncidentUser]'
GO
ALTER TABLE [dbo].[Read_IncidentUser] DROP
CONSTRAINT [FK_ReadIncidentUser_Users]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Dropping foreign keys from [dbo].[BusinessUnit]'
GO
ALTER TABLE [dbo].[BusinessUnit] DROP
CONSTRAINT [FK_BusinessUnit_BusinessUnit],
CONSTRAINT [FK_BusinessUnit_CountryRegion],
CONSTRAINT [FK_BusinessUnit_Languages]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Dropping foreign keys from [dbo].[Incident]'
GO
ALTER TABLE [dbo].[Incident] DROP
CONSTRAINT [FK_Incident_BusinessUnit],
CONSTRAINT [FK_Incident_Service],
CONSTRAINT [FK_Incident_Users],
CONSTRAINT [FK_Incident_Users1],
CONSTRAINT [FK_Incidents_Users]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Dropping foreign keys from [dbo].[KnowledgeBaseItemHistory]'
GO
ALTER TABLE [dbo].[KnowledgeBaseItemHistory] DROP
CONSTRAINT [FK_KnowledgeBaseItemHistory_Users]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Dropping foreign keys from [dbo].[License]'
GO
ALTER TABLE [dbo].[License] DROP
CONSTRAINT [FK_License_ApplicationType]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Dropping foreign keys from [dbo].[Users]'
GO
ALTER TABLE [dbo].[Users] DROP
CONSTRAINT [FK_Users_CountryRegion],
CONSTRAINT [FK_Users_PasswordFormat],
CONSTRAINT [FK_Users_Languages]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Dropping foreign keys from [dbo].[NamedUser]'
GO
ALTER TABLE [dbo].[NamedUser] DROP
CONSTRAINT [FK_NamedUser_Users]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Dropping foreign keys from [dbo].[User_BusinessUnit]'
GO
ALTER TABLE [dbo].[User_BusinessUnit] DROP
CONSTRAINT [FK_User_BusinessUnit_BusinessUnit],
CONSTRAINT [FK_User_BusinessUnit_Users]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Dropping foreign keys from [dbo].[WorkOrderTemplate]'
GO
ALTER TABLE [dbo].[WorkOrderTemplate] DROP
CONSTRAINT [FK_WorkOrderTemplate_Users]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Dropping foreign keys from [dbo].[IncidentHistory]'
GO
ALTER TABLE [dbo].[IncidentHistory] DROP
CONSTRAINT [FK_IncidentHistory_BusinessUnit],
CONSTRAINT [FK_IncidentHistory_Users],
CONSTRAINT [FK_IncidentHistory_Users1],
CONSTRAINT [FK_IncidentHistory_UsersAssignee]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Dropping foreign keys from [dbo].[Attachment_User]'
GO
ALTER TABLE [dbo].[Attachment_User] DROP
CONSTRAINT [FK_Attachment_User_Users]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Dropping foreign keys from [dbo].[ReceivedEmail]'
GO
ALTER TABLE [dbo].[ReceivedEmail] DROP
CONSTRAINT [FK_ReceivedEmail_Users]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Dropping foreign keys from [dbo].[WorkOrderHistory]'
GO
ALTER TABLE [dbo].[WorkOrderHistory] DROP
CONSTRAINT [FK_WorkOrderHistory_Users],
CONSTRAINT [FK_WorkOrderHistory_Users1]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Dropping foreign keys from [dbo].[IncidentTemplate]'
GO
ALTER TABLE [dbo].[IncidentTemplate] DROP
CONSTRAINT [FK_IncidentTemplate_BusinessUnit],
CONSTRAINT [FK_IncidentTemplate_Users],
CONSTRAINT [FK_IncidentTemplate_Users1]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Dropping foreign keys from [dbo].[SLA_BusinessUnit]'
GO
ALTER TABLE [dbo].[SLA_BusinessUnit] DROP
CONSTRAINT [FK_SLA_BusinessUnit_BusinessUnit]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Dropping foreign keys from [dbo].[User_Group]'
GO
ALTER TABLE [dbo].[User_Group] DROP
CONSTRAINT [FK_Groups_Users_Users]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Dropping foreign keys from [dbo].[KnowledgeBaseItem]'
GO
ALTER TABLE [dbo].[KnowledgeBaseItem] DROP
CONSTRAINT [FK_KnowledgeBaseItem_Users]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Dropping foreign keys from [dbo].[UserLoginLog]'
GO
ALTER TABLE [dbo].[UserLoginLog] DROP
CONSTRAINT [FK_UserLoginLog_Users]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Dropping foreign keys from [dbo].[WorkOrder]'
GO
ALTER TABLE [dbo].[WorkOrder] DROP
CONSTRAINT [FK_WorkOrder_Users],
CONSTRAINT [FK_WorkOrder_Users1]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Dropping foreign keys from [dbo].[Languages]'
GO
ALTER TABLE [dbo].[Languages] DROP
CONSTRAINT [FK_Languages_LanguageType]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Dropping constraints from [dbo].[BusinessUnit]'
GO
ALTER TABLE [dbo].[BusinessUnit] DROP CONSTRAINT [PK_BusinessUnit]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Dropping constraints from [dbo].[BusinessUnit]'
GO
ALTER TABLE [dbo].[BusinessUnit] DROP CONSTRAINT [DF_BusinessUnit_LanguageID]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Dropping constraints from [dbo].[BusinessUnit]'
GO
ALTER TABLE [dbo].[BusinessUnit] DROP CONSTRAINT [DF_BusinessUnit_CreatedOn]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Dropping constraints from [dbo].[BusinessUnit]'
GO
ALTER TABLE [dbo].[BusinessUnit] DROP CONSTRAINT [DF_BusinessUnit_ModifiedOn]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Dropping constraints from [dbo].[BusinessUnit]'
GO
ALTER TABLE [dbo].[BusinessUnit] DROP CONSTRAINT [DF_BusinessUnit_Active]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Dropping constraints from [dbo].[UserPreference]'
GO
ALTER TABLE [dbo].[UserPreference] DROP CONSTRAINT [PK_UserPreference]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Dropping constraints from [dbo].[UserPreference]'
GO
ALTER TABLE [dbo].[UserPreference] DROP CONSTRAINT [DF_UserPreference_CreatedOn]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Dropping constraints from [dbo].[UserPreference]'
GO
ALTER TABLE [dbo].[UserPreference] DROP CONSTRAINT [DF_UserPreference_UpdatedOn]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Dropping constraints from [dbo].[Users]'
GO
ALTER TABLE [dbo].[Users] DROP CONSTRAINT [PK_Users]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Dropping constraints from [dbo].[Users]'
GO
ALTER TABLE [dbo].[Users] DROP CONSTRAINT [DF_Users_PasswordFormat]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Dropping constraints from [dbo].[Users]'
GO
ALTER TABLE [dbo].[Users] DROP CONSTRAINT [DF_Users_LanguageID]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Dropping constraints from [dbo].[Users]'
GO
ALTER TABLE [dbo].[Users] DROP CONSTRAINT [DF_Users_CreatedOn]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Dropping constraints from [dbo].[Users]'
GO
ALTER TABLE [dbo].[Users] DROP CONSTRAINT [DF_Users_ModifiedOn]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Dropping constraints from [dbo].[Users]'
GO
ALTER TABLE [dbo].[Users] DROP CONSTRAINT [DF_Users_ReceiveEmails]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Dropping constraints from [dbo].[Users]'
GO
ALTER TABLE [dbo].[Users] DROP CONSTRAINT [DF_Users_Active]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Dropping constraints from [dbo].[UserPreferenceType]'
GO
ALTER TABLE [dbo].[UserPreferenceType] DROP CONSTRAINT [PK_UserPreferenceType]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Dropping index [IX_Users] from [dbo].[Users]'
GO
DROP INDEX [IX_Users] ON [dbo].[Users]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Dropping [dbo].[UserPreferenceType]'
GO
DROP TABLE [dbo].[UserPreferenceType]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating [dbo].[BusinessUnitTemplate]'
GO
CREATE TABLE [dbo].[BusinessUnitTemplate]
(
[BusinessUnitTemplateID] [bigint] NOT NULL,
[BusinessUnitName] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[Division] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[WebSiteUrl] [nvarchar] (200) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[MainPhone] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[OtherPhone] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[Fax] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[Email] [nvarchar] (200) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[Street] [nvarchar] (200) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[City] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[StateProvince] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[ZIPPostalCode] [nvarchar] (25) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CountryRegionID] [bigint] NULL,
[ParentBusinessUnitID] [bigint] NULL,
[Note] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[LanguageID] [bigint] NULL,
[Active] [bit] NULL CONSTRAINT [DF_BusinessUnitTemplate_Active] DEFAULT ((1)),
[CustomFields] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CustomPrintHeader] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CustomPrintFooter] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL
)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating primary key [PK_BusinessUnitTemplate] on [dbo].[BusinessUnitTemplate]'
GO
ALTER TABLE [dbo].[BusinessUnitTemplate] ADD CONSTRAINT [PK_BusinessUnitTemplate] PRIMARY KEY CLUSTERED  ([BusinessUnitTemplateID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Altering [dbo].[IncidentHistory]'
GO
ALTER TABLE [dbo].[IncidentHistory] ADD
[ConfigurationItemID] [bigint] NULL
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Rebuilding [dbo].[BusinessUnit]'
GO
CREATE TABLE [dbo].[tmp_rg_xx_BusinessUnit]
(
[BusinessUnitID] [bigint] NOT NULL IDENTITY(1, 1),
[BusinessUnitName] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
[Division] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[WebSiteUrl] [nvarchar] (200) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[MainPhone] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[OtherPhone] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[Fax] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[Email] [nvarchar] (200) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[Street] [nvarchar] (200) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[City] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[StateProvince] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[ZIPPostalCode] [nvarchar] (25) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CountryRegionID] [bigint] NULL,
[ParentBusinessUnitID] [bigint] NULL,
[Note] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[LanguageID] [bigint] NULL CONSTRAINT [DF_BusinessUnit_LanguageID] DEFAULT ((1)),
[CreatedOn] [datetime] NOT NULL CONSTRAINT [DF_BusinessUnit_CreatedOn] DEFAULT (getdate()),
[ModifiedOn] [datetime] NOT NULL CONSTRAINT [DF_BusinessUnit_ModifiedOn] DEFAULT (getdate()),
[Active] [bit] NOT NULL CONSTRAINT [DF_BusinessUnit_Active] DEFAULT ((1)),
[BusinessUnitTemplateID] [bigint] NULL,
[BusinessUnitType] [nvarchar] (20) COLLATE SQL_Latin1_General_CP1_CI_AS NULL CONSTRAINT [DF_BusinessUnit_BusinessUnitType] DEFAULT (N'RegularBusinessUnit')
)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
SET IDENTITY_INSERT [dbo].[tmp_rg_xx_BusinessUnit] ON
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
INSERT INTO [dbo].[tmp_rg_xx_BusinessUnit]([BusinessUnitID], [BusinessUnitName], [Division], [WebSiteUrl], [MainPhone], [OtherPhone], [Fax], [Email], [Street], [City], [StateProvince], [ZIPPostalCode], [CountryRegionID], [ParentBusinessUnitID], [Note], [LanguageID], [CreatedOn], [ModifiedOn], [Active]) SELECT [BusinessUnitID], [BusinessUnitName], [Division], [WebSiteUrl], [MainPhone], [OtherPhone], [Fax], [Email], [Street], [City], [StateProvince], [ZIPPostalCode], [CountryRegionID], [ParentBusinessUnitID], [Note], [LanguageID], [CreatedOn], [ModifiedOn], [Active] FROM [dbo].[BusinessUnit]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
SET IDENTITY_INSERT [dbo].[tmp_rg_xx_BusinessUnit] OFF
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
DROP TABLE [dbo].[BusinessUnit]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
EXEC sp_rename N'[dbo].[tmp_rg_xx_BusinessUnit]', N'BusinessUnit'
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating primary key [PK_BusinessUnit] on [dbo].[BusinessUnit]'
GO
ALTER TABLE [dbo].[BusinessUnit] ADD CONSTRAINT [PK_BusinessUnit] PRIMARY KEY CLUSTERED  ([BusinessUnitID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Altering [dbo].[IncidentTemplate]'
GO
ALTER TABLE [dbo].[IncidentTemplate] ADD
[ConfigurationItemID] [bigint] NULL,
[CustomFields] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CustomPrintHeader] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CustomPrintFooter] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[IncidentTemplateType] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL CONSTRAINT [DF_IncidentTemplate_IncidentTemplateType] DEFAULT (N'RegularIncidentTemplate')
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Altering [dbo].[NamedUser]'
GO
ALTER TABLE [dbo].[NamedUser] ADD
[LicenseID] [bigint] NOT NULL CONSTRAINT [DF_NamedUser_LicenseID] DEFAULT ((1))
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Altering [dbo].[Role]'
GO
ALTER TABLE [dbo].[Role] ADD
[RoleType] [nvarchar] (200) COLLATE SQL_Latin1_General_CP1_CI_AS NULL
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Altering [dbo].[Languages]'
GO
ALTER TABLE [dbo].[Languages] ALTER COLUMN [LanguageTypeID] [bigint] NOT NULL

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating [dbo].[ConfigurationItemTemplate]'
GO
CREATE TABLE [dbo].[ConfigurationItemTemplate]
(
[ConfigurationItemTemplateID] [bigint] NOT NULL IDENTITY(1, 1),
[ConfigurationItemTemplateName] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
[Description] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CustomFields] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[ConfigurationItemName] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[ConfigurationItemCategoryID] [bigint] NULL,
[ConfigurationItemTemplateType] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL CONSTRAINT [DF_ConfigurationItemTemplate_ConfigurationItemTemplateType] DEFAULT (N'RegularConfigurationItemTemplate')
)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating primary key [PK_ConfigurationItemTemplate] on [dbo].[ConfigurationItemTemplate]'
GO
ALTER TABLE [dbo].[ConfigurationItemTemplate] ADD CONSTRAINT [PK_ConfigurationItemTemplate] PRIMARY KEY CLUSTERED  ([ConfigurationItemTemplateID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating [dbo].[TaggedIncidents]'
GO
CREATE TABLE [dbo].[TaggedIncidents]
(
[TaggedIncidentID] [bigint] NOT NULL IDENTITY(1, 1),
[UserID] [bigint] NOT NULL,
[IncidentID] [bigint] NOT NULL,
[TagID] [bigint] NOT NULL,
[TimeStamp] [datetime] NOT NULL CONSTRAINT [DF_TaggedIncidents_TimeStamp] DEFAULT (getdate())
)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating primary key [PK_TaggedIncidents] on [dbo].[TaggedIncidents]'
GO
ALTER TABLE [dbo].[TaggedIncidents] ADD CONSTRAINT [PK_TaggedIncidents] PRIMARY KEY CLUSTERED  ([TaggedIncidentID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating [dbo].[OwnerInfo]'
GO
CREATE TABLE [dbo].[OwnerInfo]
(
[ID] [bigint] NOT NULL IDENTITY(1, 1),
[Name] [nvarchar] (128) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[Email] [nvarchar] (256) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CreatedOn] [datetime] NOT NULL CONSTRAINT [DF_OwnerInfo_CreatedOn] DEFAULT (getdate())
)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating primary key [PK_OwnerInfo] on [dbo].[OwnerInfo]'
GO
ALTER TABLE [dbo].[OwnerInfo] ADD CONSTRAINT [PK_OwnerInfo] PRIMARY KEY CLUSTERED  ([ID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Altering [dbo].[WorkOrderTemplate]'
GO
ALTER TABLE [dbo].[WorkOrderTemplate] ADD
[CustomFields] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CustomPrintHeader] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CustomPrintFooter] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[BusinessUnitID] [bigint] NULL,
[ServiceUserID] [bigint] NULL,
[ConfigurationItemID] [bigint] NULL
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Altering [dbo].[WorkOrder]'
GO
ALTER TABLE [dbo].[WorkOrder] ADD
[WorkOrderTemplateID] [bigint] NULL,
[CF1] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF2] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF3] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF4] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF5] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF6] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF7] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF8] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF9] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF10] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF11] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF12] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF13] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF14] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF15] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF16] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF17] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF18] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF19] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF20] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[ConfigurationItemID] [bigint] NULL,
[ServiceUserID] [bigint] NULL,
[BusinessUnitID] [bigint] NULL
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating [dbo].[UserTemplate]'
GO
CREATE TABLE [dbo].[UserTemplate]
(
[UserTemplateID] [bigint] NOT NULL IDENTITY(1, 1),
[FirstName] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[LastName] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[Description] [nvarchar] (1000) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[TelephoneNumber] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[Office] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[Email] [nvarchar] (200) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[WebPage] [nvarchar] (200) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[Street] [nvarchar] (500) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[POBox] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[City] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[StateProvince] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[ZIPPostalCode] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CountryRegionID] [bigint] NULL,
[TelephoneHome] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[TelephonePage] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[TelephoneMobile] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[TelephoneFax] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[TelephoneIPPhone] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[Notes] [nvarchar] (500) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[Title] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[Department] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[LanguageID] [bigint] NULL,
[ReceiveEmails] [bit] NULL CONSTRAINT [DF_UserTemplate_ReceiveEmails] DEFAULT ((1)),
[Active] [bit] NULL CONSTRAINT [DF_UserTemplate_Active] DEFAULT ((1)),
[CustomFields] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CustomPrintHeader] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CustomPrintFooter] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[UserTemplateName] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL
)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating primary key [PK_UserTemplate] on [dbo].[UserTemplate]'
GO
ALTER TABLE [dbo].[UserTemplate] ADD CONSTRAINT [PK_UserTemplate] PRIMARY KEY CLUSTERED  ([UserTemplateID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating [dbo].[ChatMessages]'
GO
CREATE TABLE [dbo].[ChatMessages]
(
[ChatMessageID] [bigint] NOT NULL IDENTITY(1, 1),
[MessageBody] [nvarchar] (max) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
[TimeStamp] [datetime] NOT NULL CONSTRAINT [DF_ChatMessages_TimeStamp] DEFAULT (getdate()),
[ChatID] [bigint] NOT NULL,
[UserID] [bigint] NOT NULL
)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating primary key [PK_ChatMessages] on [dbo].[ChatMessages]'
GO
ALTER TABLE [dbo].[ChatMessages] ADD CONSTRAINT [PK_ChatMessages] PRIMARY KEY CLUSTERED  ([ChatMessageID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating [dbo].[Chats]'
GO
CREATE TABLE [dbo].[Chats]
(
[ChatID] [bigint] NOT NULL IDENTITY(1, 1),
[HiddenChat] [bit] NOT NULL CONSTRAINT [DF_Chats_HiddenChat] DEFAULT ((0))
)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating primary key [PK_Chats] on [dbo].[Chats]'
GO
ALTER TABLE [dbo].[Chats] ADD CONSTRAINT [PK_Chats] PRIMARY KEY CLUSTERED  ([ChatID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating [dbo].[TaggedChats]'
GO
CREATE TABLE [dbo].[TaggedChats]
(
[TaggedChatID] [bigint] NOT NULL IDENTITY(1, 1),
[UserID] [bigint] NOT NULL,
[ChatID] [bigint] NOT NULL,
[TagID] [bigint] NOT NULL,
[TimeStamp] [datetime] NOT NULL CONSTRAINT [DF_TaggedChats_TimeStamp] DEFAULT (getdate())
)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating primary key [PK_TaggedChats] on [dbo].[TaggedChats]'
GO
ALTER TABLE [dbo].[TaggedChats] ADD CONSTRAINT [PK_TaggedChats] PRIMARY KEY CLUSTERED  ([TaggedChatID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating [dbo].[TaggedUsers]'
GO
CREATE TABLE [dbo].[TaggedUsers]
(
[TaggedUserID] [bigint] NOT NULL IDENTITY(1, 1),
[UserID] [bigint] NOT NULL,
[TaggedUserEntityID] [bigint] NOT NULL,
[TagID] [bigint] NOT NULL,
[TimeStamp] [datetime] NOT NULL CONSTRAINT [DF_TaggedUsers_TimeStamp] DEFAULT (getdate())
)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating primary key [PK_TaggedUsers] on [dbo].[TaggedUsers]'
GO
ALTER TABLE [dbo].[TaggedUsers] ADD CONSTRAINT [PK_TaggedUsers] PRIMARY KEY CLUSTERED  ([TaggedUserID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Rebuilding [dbo].[Users]'
GO
CREATE TABLE [dbo].[tmp_rg_xx_Users]
(
[UserID] [bigint] NOT NULL IDENTITY(1, 1),
[FirstName] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[LastName] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[Description] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[TelephoneNumber] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[Office] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[Email] [nvarchar] (200) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
[WebPage] [nvarchar] (200) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[Street] [nvarchar] (200) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[POBox] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[City] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[StateProvince] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[ZIPPostalCode] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CountryRegionID] [bigint] NULL,
[TelephoneHome] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[TelephonePage] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[TelephoneMobile] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[TelephoneFax] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[TelephoneIPPhone] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[Notes] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[Title] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[Department] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[Password] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
[PasswordFormatID] [bigint] NOT NULL CONSTRAINT [DF_Users_PasswordFormat] DEFAULT ((1)),
[UserName] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
[GUID] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[LanguageID] [bigint] NULL CONSTRAINT [DF_Users_LanguageID] DEFAULT ((1)),
[UserCreatedOn] [datetime] NOT NULL CONSTRAINT [DF_Users_CreatedOn] DEFAULT (getdate()),
[UserModifiedOn] [datetime] NOT NULL CONSTRAINT [DF_Users_ModifiedOn] DEFAULT (getdate()),
[ReceiveEmails] [bit] NOT NULL CONSTRAINT [DF_Users_ReceiveEmails] DEFAULT ((1)),
[Active] [bit] NOT NULL CONSTRAINT [DF_Users_Active] DEFAULT ((1)),
[UserTemplateID] [bigint] NULL,
[UserType] [nvarchar] (200) COLLATE SQL_Latin1_General_CP1_CI_AS NULL CONSTRAINT [DF_Users_UserType] DEFAULT (N'RegularUser'),
[Version] [bigint] NOT NULL CONSTRAINT [DF_Users_Version] DEFAULT ((1))
)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
SET IDENTITY_INSERT [dbo].[tmp_rg_xx_Users] ON
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
INSERT INTO [dbo].[tmp_rg_xx_Users]([UserID], [FirstName], [LastName], [Description], [TelephoneNumber], [Office], [Email], [WebPage], [Street], [POBox], [City], [StateProvince], [ZIPPostalCode], [CountryRegionID], [TelephoneHome], [TelephonePage], [TelephoneMobile], [TelephoneFax], [TelephoneIPPhone], [Notes], [Title], [Department], [Password], [PasswordFormatID], [UserName], [GUID], [LanguageID], [UserCreatedOn], [UserModifiedOn], [ReceiveEmails], [Active]) SELECT [UserID], [FirstName], [LastName], [Description], [TelephoneNumber], [Office], [Email], [WebPage], [Street], [POBox], [City], [StateProvince], [ZIPPostalCode], [CountryRegionID], [TelephoneHome], [TelephonePage], [TelephoneMobile], [TelephoneFax], [TelephoneIPPhone], [Notes], [Title], [Department], [Password], [PasswordFormatID], [UserName], [GUID], [LanguageID], [UserCreatedOn], [UserModifiedOn], [ReceiveEmails], [Active] FROM [dbo].[Users]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
SET IDENTITY_INSERT [dbo].[tmp_rg_xx_Users] OFF
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
DROP TABLE [dbo].[Users]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
EXEC sp_rename N'[dbo].[tmp_rg_xx_Users]', N'Users'
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating primary key [PK_Users] on [dbo].[Users]'
GO
ALTER TABLE [dbo].[Users] ADD CONSTRAINT [PK_Users] PRIMARY KEY CLUSTERED  ([UserID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Altering [dbo].[License]'
GO
ALTER TABLE [dbo].[License] ALTER COLUMN [ApplicationTypeID] [bigint] NULL
ALTER TABLE [dbo].[License] ALTER COLUMN [UserName] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL
ALTER TABLE [dbo].[License] ALTER COLUMN [NamedLicences] [smallint] NULL
ALTER TABLE [dbo].[License] ALTER COLUMN [ConcurentLicences] [smallint] NULL

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Altering [dbo].[Groups]'
GO
ALTER TABLE [dbo].[Groups] ADD
[GroupType] [nvarchar] (200) COLLATE SQL_Latin1_General_CP1_CI_AS NULL CONSTRAINT [DF_Groups_GroupType] DEFAULT (N'RegularGroup')
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Altering [dbo].[Incident]'
GO
ALTER TABLE [dbo].[Incident] ADD
[ConfigurationItemID] [bigint] NULL,
[CF1] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF2] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF3] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF4] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF5] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF6] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF7] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF8] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF9] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF10] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF11] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF12] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF13] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF14] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF15] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF16] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF17] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF18] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF19] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF20] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[IncidentTemplateID] [bigint] NULL,
[Version] [bigint] NOT NULL CONSTRAINT [DF_Incident_Version] DEFAULT ((1)),
[HiddenIncident] [bit] NOT NULL CONSTRAINT [DF_Incident_HiddenIncident] DEFAULT ((0))
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
ALTER TABLE [dbo].[Incident] ALTER COLUMN [ServiceID] [bigint] NULL

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating [dbo].[ConfigurationItemCategory]'
GO
CREATE TABLE [dbo].[ConfigurationItemCategory]
(
[ConfigurationItemCategoryID] [bigint] NOT NULL IDENTITY(1, 1),
[ConfigurationItemCategoryParent] [bigint] NULL,
[ConfigurationItemCategoryName] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL
)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating primary key [PK_ConfigurationItemCategory] on [dbo].[ConfigurationItemCategory]'
GO
ALTER TABLE [dbo].[ConfigurationItemCategory] ADD CONSTRAINT [PK_ConfigurationItemCategory] PRIMARY KEY CLUSTERED  ([ConfigurationItemCategoryID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating [dbo].[ConfigurationItem]'
GO
CREATE TABLE [dbo].[ConfigurationItem]
(
[ConfigurationItemID] [bigint] NOT NULL IDENTITY(1, 1),
[ConfigurationItemName] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
[ConfigurationItemTemplateID] [bigint] NOT NULL,
[CF1] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF2] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF3] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF4] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF5] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF6] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF7] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF8] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF9] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF10] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF11] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF12] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF13] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF14] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF15] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF16] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF17] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF18] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF19] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[CF20] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[Description] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[ConfigurationItemCategoryID] [bigint] NOT NULL
)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating primary key [PK_ConfigurationItem] on [dbo].[ConfigurationItem]'
GO
ALTER TABLE [dbo].[ConfigurationItem] ADD CONSTRAINT [PK_ConfigurationItem] PRIMARY KEY CLUSTERED  ([ConfigurationItemID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating [dbo].[Role_UserTemplate]'
GO
CREATE TABLE [dbo].[Role_UserTemplate]
(
[RoleUserTemplateID] [bigint] NOT NULL IDENTITY(1, 1),
[UserTemplateID] [bigint] NULL,
[RoleID] [bigint] NULL
)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating primary key [PK_Role_UserTemplate] on [dbo].[Role_UserTemplate]'
GO
ALTER TABLE [dbo].[Role_UserTemplate] ADD CONSTRAINT [PK_Role_UserTemplate] PRIMARY KEY CLUSTERED  ([RoleUserTemplateID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating [dbo].[Tags]'
GO
CREATE TABLE [dbo].[Tags]
(
[TagID] [bigint] NOT NULL IDENTITY(1, 1),
[Name] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL
)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating primary key [PK_Tags] on [dbo].[Tags]'
GO
ALTER TABLE [dbo].[Tags] ADD CONSTRAINT [PK_Tags] PRIMARY KEY CLUSTERED  ([TagID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Rebuilding [dbo].[UserPreference]'
GO
CREATE TABLE [dbo].[tmp_rg_xx_UserPreference]
(
[ID] [bigint] NOT NULL IDENTITY(1, 1),
[UserID] [bigint] NOT NULL,
[Name] [nvarchar] (1000) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
[Value] [nvarchar] (1000) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL
)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
INSERT INTO [dbo].[tmp_rg_xx_UserPreference]([UserID]) SELECT [UserID] FROM [dbo].[UserPreference]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
DROP TABLE [dbo].[UserPreference]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
EXEC sp_rename N'[dbo].[tmp_rg_xx_UserPreference]', N'UserPreference'
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating primary key [PK_UserPreference] on [dbo].[UserPreference]'
GO
ALTER TABLE [dbo].[UserPreference] ADD CONSTRAINT [PK_UserPreference] PRIMARY KEY CLUSTERED  ([ID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating [dbo].[UserTemplate_BusinessUnit]'
GO
CREATE TABLE [dbo].[UserTemplate_BusinessUnit]
(
[UserTemplateID] [bigint] NOT NULL,
[BusinessUnitID] [bigint] NOT NULL,
[UserTemplateBusinessUnitID] [bigint] NOT NULL IDENTITY(1, 1)
)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating primary key [PK_UserTemplate_BusinessUnit] on [dbo].[UserTemplate_BusinessUnit]'
GO
ALTER TABLE [dbo].[UserTemplate_BusinessUnit] ADD CONSTRAINT [PK_UserTemplate_BusinessUnit] PRIMARY KEY CLUSTERED  ([UserTemplateBusinessUnitID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating [dbo].[UserTemplate_Group]'
GO
CREATE TABLE [dbo].[UserTemplate_Group]
(
[UserTemplateID] [bigint] NOT NULL,
[GroupID] [bigint] NOT NULL,
[UserTemplateGroupID] [bigint] NOT NULL IDENTITY(1, 1)
)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating primary key [PK_UserTemplate_Group] on [dbo].[UserTemplate_Group]'
GO
ALTER TABLE [dbo].[UserTemplate_Group] ADD CONSTRAINT [PK_UserTemplate_Group] PRIMARY KEY CLUSTERED  ([UserTemplateGroupID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating [dbo].[UserTemplate_Role]'
GO
CREATE TABLE [dbo].[UserTemplate_Role]
(
[UserTemplateID] [bigint] NOT NULL,
[RoleID] [bigint] NOT NULL,
[UserTemplateRoleID] [bigint] NOT NULL IDENTITY(1, 1)
)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating primary key [PK_UserTemplate_Role] on [dbo].[UserTemplate_Role]'
GO
ALTER TABLE [dbo].[UserTemplate_Role] ADD CONSTRAINT [PK_UserTemplate_Role] PRIMARY KEY CLUSTERED  ([UserTemplateRoleID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating [dbo].[ActionLog]'
GO
CREATE TABLE [dbo].[ActionLog]
(
[ID] [bigint] NOT NULL IDENTITY(1, 1),
[ActionType] [nvarchar] (200) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
[ActionData] [nvarchar] (200) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
[CreatedOn] [datetime] NOT NULL
)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating primary key [PK_ActionLog] on [dbo].[ActionLog]'
GO
ALTER TABLE [dbo].[ActionLog] ADD CONSTRAINT [PK_ActionLog] PRIMARY KEY CLUSTERED  ([ID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating [dbo].[AuthenticationEvidence]'
GO
CREATE TABLE [dbo].[AuthenticationEvidence]
(
[AuthenticationEvidenceID] [bigint] NOT NULL IDENTITY(1, 1),
[AuthenticatedUserID] [bigint] NOT NULL,
[ExpirationTime] [datetime] NOT NULL,
[IsValid] [bit] NOT NULL,
[ExpendsConcurentLicense] [bit] NOT NULL,
[LicenceAccountabilityTime] [datetime] NOT NULL
)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating primary key [PK_AuthenticationEvidence] on [dbo].[AuthenticationEvidence]'
GO
ALTER TABLE [dbo].[AuthenticationEvidence] ADD CONSTRAINT [PK_AuthenticationEvidence] PRIMARY KEY CLUSTERED  ([AuthenticationEvidenceID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating [dbo].[InstanceConfiguration]'
GO
CREATE TABLE [dbo].[InstanceConfiguration]
(
[ID] [bigint] NOT NULL IDENTITY(1, 1),
[Url] [nvarchar] (256) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
[Shadow] [nvarchar] (128) COLLATE SQL_Latin1_General_CP1_CI_AS NULL
)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating primary key [PK_InstanceConfiguration] on [dbo].[InstanceConfiguration]'
GO
ALTER TABLE [dbo].[InstanceConfiguration] ADD CONSTRAINT [PK_InstanceConfiguration] PRIMARY KEY CLUSTERED  ([ID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating [dbo].[UsageStatistic]'
GO
CREATE TABLE [dbo].[UsageStatistic]
(
[ID] [bigint] NOT NULL IDENTITY(1, 1),
[IncidentCount] [bigint] NOT NULL,
[LastLogin] [datetime] NULL,
[LastIncidentCreatedOn] [datetime] NULL,
[ModifiedOn] [datetime] NOT NULL,
[CreatedOn] [datetime] NOT NULL
)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating primary key [PK_UsageStatistics] on [dbo].[UsageStatistic]'
GO
ALTER TABLE [dbo].[UsageStatistic] ADD CONSTRAINT [PK_UsageStatistics] PRIMARY KEY CLUSTERED  ([ID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating [dbo].[Widgets]'
GO
CREATE TABLE [dbo].[Widgets]
(
[WidgetID] [bigint] NOT NULL IDENTITY(1, 1),
[Name] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
[Value] [nvarchar] (4000) COLLATE SQL_Latin1_General_CP1_CI_AS NULL
)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating primary key [PK_Widgets] on [dbo].[Widgets]'
GO
ALTER TABLE [dbo].[Widgets] ADD CONSTRAINT [PK_Widgets] PRIMARY KEY CLUSTERED  ([WidgetID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating index [IX_Widgets] on [dbo].[Widgets]'
GO
CREATE NONCLUSTERED INDEX [IX_Widgets] ON [dbo].[Widgets] ([WidgetID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating [dbo].[sp_show_huge_tables]'
GO

CREATE PROC sp_show_huge_tables
(
@top			int	= NULL,
@include_system_tables 	bit 	= 0
)
AS
/*************************************************************************************************
		Copyright  1997 - 2002 Narayana Vyas Kondreddi. All rights reserved.
                                          
Purpose:	To list the size of all tables in the database in descending order (that is biggere tables first). 
		Output can be restricted to top n tables. That is you can pass the value 3 to @top parameter to 
		see the top 3 biggest tables in your database. Optionally, you can use @include_system_tables 
		parameter, to include systemt tables in the output.
		NOTE: Always create this procedure in the master database and call it from the required databases,
		as if the stored procedure is created in that database (That is, don't prefix the stored procedure
		with the database name).

Written by:	Narayana Vyas Kondreddi
		http://vyaskn.tripod.com

Tested on: 	SQL Server 7.0

Date created:	January-22-2002 21:37 GMT

Date modified:	February-18-2002 11:31 GMT

Email: 		vyaskn@hotmail.com

Examples:

To list all the user tables in the database along with their sizes:
EXEC sp_show_huge_tables

To see the top three biggest tables in your database:
EXEC sp_show_huge_tables 3

To list all the user AND system tables in the database along with their sizes:
EXEC sp_show_huge_tables @include_system_tables = 1


To see the top three biggest user or system tables in your database:
EXEC sp_show_huge_tables 3, 1
*************************************************************************************************/

BEGIN
	IF @top > 0
	SET ROWCOUNT @top

	SELECT [Table Name], (SELECT rows FROM sysindexes s WHERE s.indid < 2 AND s.id = OBJECT_ID(a.[Table Name])) AS [Row count], [Total space used (MB)] FROM  
	(
	SELECT	QUOTENAME(USER_NAME(o.uid)) + '.' + QUOTENAME(OBJECT_NAME(i.id)) AS [Table Name],
		CONVERT(numeric(15,2),(((CONVERT(numeric(15,2),SUM(i.reserved)) * (SELECT low FROM master.dbo.spt_values (NOLOCK) WHERE number = 1 AND type = 'E')) / 1024.)/1024.)) AS [Total space used (MB)]
	FROM	sysindexes i (NOLOCK)
			INNER JOIN 
		sysobjects o (NOLOCK) 
			ON 
		i.id = o.id AND 
		((@include_system_tables = 1 AND o.type IN ('U', 'S')) OR o.type = 'U') AND 
		((@include_system_tables = 1)OR (OBJECTPROPERTY(i.id, 'IsMSShipped') = 0))
	WHERE	indid IN (0, 1, 255)
	GROUP BY	QUOTENAME(USER_NAME(o.uid)) + '.' + QUOTENAME(OBJECT_NAME(i.id))
	
	) as a
ORDER BY	[Total space used (MB)] DESC


	SET ROWCOUNT 0
END


GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating index [IX_Email] on [dbo].[Email]'
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_Email] ON [dbo].[Email] ([MessageID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating index [IX_ReceivedEmail] on [dbo].[ReceivedEmail]'
GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ReceivedEmail] ON [dbo].[ReceivedEmail] ([MessageID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding constraints to [dbo].[InstanceConfiguration]'
GO
ALTER TABLE [dbo].[InstanceConfiguration] ADD CONSTRAINT [IX_InstanceConfiguration_UrlAndShadow] UNIQUE NONCLUSTERED  ([Url], [Shadow])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding constraints to [dbo].[Tags]'
GO
ALTER TABLE [dbo].[Tags] ADD CONSTRAINT [IX_Tags] UNIQUE NONCLUSTERED  ([Name])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding constraints to [dbo].[Users]'
GO
ALTER TABLE [dbo].[Users] ADD CONSTRAINT [IX_Email] UNIQUE NONCLUSTERED  ([Email])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
ALTER TABLE [dbo].[Users] ADD CONSTRAINT [IX_Users] UNIQUE NONCLUSTERED  ([UserName])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding constraints to [dbo].[Incident]'
GO
ALTER TABLE [dbo].[Incident] ADD CONSTRAINT [DF_Incident_ServiceID] DEFAULT ((1)) FOR [ServiceID]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding constraints to [dbo].[Languages]'
GO
ALTER TABLE [dbo].[Languages] ADD CONSTRAINT [DF_Languages_LanguageTypeID] DEFAULT (1) FOR [LanguageTypeID]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[Announcement]'
GO
ALTER TABLE [dbo].[Announcement] WITH NOCHECK ADD
CONSTRAINT [FK_Announcement_Users] FOREIGN KEY ([AuthorID]) REFERENCES [dbo].[Users] ([UserID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[Attachment_User]'
GO
ALTER TABLE [dbo].[Attachment_User] WITH NOCHECK ADD
CONSTRAINT [FK_Attachment_User_Users] FOREIGN KEY ([UserID]) REFERENCES [dbo].[Users] ([UserID]) ON DELETE CASCADE
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[BusinessUnit]'
GO
ALTER TABLE [dbo].[BusinessUnit] WITH NOCHECK ADD
CONSTRAINT [FK_BusinessUnit_BusinessUnit] FOREIGN KEY ([ParentBusinessUnitID]) REFERENCES [dbo].[BusinessUnit] ([BusinessUnitID]),
CONSTRAINT [FK_BusinessUnit_CountryRegion] FOREIGN KEY ([CountryRegionID]) REFERENCES [dbo].[CountryRegion] ([CountryRegionID]),
CONSTRAINT [FK_BusinessUnit_Languages] FOREIGN KEY ([LanguageID]) REFERENCES [dbo].[Languages] ([LanguageID]),
CONSTRAINT [FK_BusinessUnit_BusinessUnitTemplate] FOREIGN KEY ([BusinessUnitTemplateID]) REFERENCES [dbo].[BusinessUnitTemplate] ([BusinessUnitTemplateID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[BusinessUnitTemplate]'
GO
ALTER TABLE [dbo].[BusinessUnitTemplate] WITH NOCHECK ADD
CONSTRAINT [FK_BusinessUnitTemplate_BusinessUnit] FOREIGN KEY ([ParentBusinessUnitID]) REFERENCES [dbo].[BusinessUnit] ([BusinessUnitID]),
CONSTRAINT [FK_BusinessUnitTemplate_CountryRegion] FOREIGN KEY ([CountryRegionID]) REFERENCES [dbo].[CountryRegion] ([CountryRegionID]),
CONSTRAINT [FK_BusinessUnitTemplate_Languages] FOREIGN KEY ([LanguageID]) REFERENCES [dbo].[Languages] ([LanguageID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[Incident]'
GO
ALTER TABLE [dbo].[Incident] WITH NOCHECK ADD
CONSTRAINT [FK_Incident_BusinessUnit] FOREIGN KEY ([BusinessUnitID]) REFERENCES [dbo].[BusinessUnit] ([BusinessUnitID]),
CONSTRAINT [FK_Incident_ConfigurationItem] FOREIGN KEY ([ConfigurationItemID]) REFERENCES [dbo].[ConfigurationItem] ([ConfigurationItemID]),
CONSTRAINT [FK_Incident_Users] FOREIGN KEY ([AssigneeID]) REFERENCES [dbo].[Users] ([UserID]),
CONSTRAINT [FK_Incident_Users1] FOREIGN KEY ([CreatedBy]) REFERENCES [dbo].[Users] ([UserID]),
CONSTRAINT [FK_Incidents_Users] FOREIGN KEY ([ServiceUserID]) REFERENCES [dbo].[Users] ([UserID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[IncidentHistory]'
GO
ALTER TABLE [dbo].[IncidentHistory] WITH NOCHECK ADD
CONSTRAINT [FK_IncidentHistory_BusinessUnit] FOREIGN KEY ([BusinessUnitID]) REFERENCES [dbo].[BusinessUnit] ([BusinessUnitID]),
CONSTRAINT [FK_IncidentHistory_Users] FOREIGN KEY ([ServiceUserID]) REFERENCES [dbo].[Users] ([UserID]),
CONSTRAINT [FK_IncidentHistory_Users1] FOREIGN KEY ([CreatedBy]) REFERENCES [dbo].[Users] ([UserID]),
CONSTRAINT [FK_IncidentHistory_UsersAssignee] FOREIGN KEY ([AssigneeID]) REFERENCES [dbo].[Users] ([UserID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[WorkOrder]'
GO
ALTER TABLE [dbo].[WorkOrder] WITH NOCHECK ADD
CONSTRAINT [FK_WorkOrder_BusinessUnit] FOREIGN KEY ([BusinessUnitID]) REFERENCES [dbo].[BusinessUnit] ([BusinessUnitID]),
CONSTRAINT [FK_WorkOrder_ConfigurationItem] FOREIGN KEY ([ConfigurationItemID]) REFERENCES [dbo].[ConfigurationItem] ([ConfigurationItemID]),
CONSTRAINT [FK_WorkOrder_Users] FOREIGN KEY ([CreatedBy]) REFERENCES [dbo].[Users] ([UserID]),
CONSTRAINT [FK_WorkOrder_Users1] FOREIGN KEY ([CreatedBy]) REFERENCES [dbo].[Users] ([UserID]),
CONSTRAINT [FK_WorkOrder_Users2] FOREIGN KEY ([ServiceUserID]) REFERENCES [dbo].[Users] ([UserID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[WorkOrderTemplate]'
GO
ALTER TABLE [dbo].[WorkOrderTemplate] WITH NOCHECK ADD
CONSTRAINT [FK_WorkOrderTemplate_BusinessUnit] FOREIGN KEY ([BusinessUnitID]) REFERENCES [dbo].[BusinessUnit] ([BusinessUnitID]),
CONSTRAINT [FK_WorkOrderTemplate_ConfigurationItem] FOREIGN KEY ([ConfigurationItemID]) REFERENCES [dbo].[ConfigurationItem] ([ConfigurationItemID]),
CONSTRAINT [FK_WorkOrderTemplate_Users] FOREIGN KEY ([AssigneeID]) REFERENCES [dbo].[Users] ([UserID]),
CONSTRAINT [FK_WorkOrderTemplate_Users1] FOREIGN KEY ([ServiceUserID]) REFERENCES [dbo].[Users] ([UserID]),
CONSTRAINT [FK_WorkOrderTemplate_WorkOrder] FOREIGN KEY ([WorkOrderTemplateID]) REFERENCES [dbo].[WorkOrder] ([WorkOrderID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[IncidentTemplate]'
GO
ALTER TABLE [dbo].[IncidentTemplate] WITH NOCHECK ADD
CONSTRAINT [FK_IncidentTemplate_ConfigurationItem] FOREIGN KEY ([ConfigurationItemID]) REFERENCES [dbo].[ConfigurationItem] ([ConfigurationItemID]),
CONSTRAINT [FK_IncidentTemplate_Users] FOREIGN KEY ([CreatedBy]) REFERENCES [dbo].[Users] ([UserID]),
CONSTRAINT [FK_IncidentTemplate_Users1] FOREIGN KEY ([AssigneeID]) REFERENCES [dbo].[Users] ([UserID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[ConfigurationItemCategory]'
GO
ALTER TABLE [dbo].[ConfigurationItemCategory] WITH NOCHECK ADD
CONSTRAINT [FK_ConfigurationItemCategory_ConfigurationItemCategory] FOREIGN KEY ([ConfigurationItemCategoryParent]) REFERENCES [dbo].[ConfigurationItemCategory] ([ConfigurationItemCategoryID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[ConfigurationItemTemplate]'
GO
ALTER TABLE [dbo].[ConfigurationItemTemplate] WITH NOCHECK ADD
CONSTRAINT [FK_ConfigurationItemTemplate_ConfigurationItemCategory] FOREIGN KEY ([ConfigurationItemCategoryID]) REFERENCES [dbo].[ConfigurationItemCategory] ([ConfigurationItemCategoryID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[KnowledgeBaseItem]'
GO
ALTER TABLE [dbo].[KnowledgeBaseItem] WITH NOCHECK ADD
CONSTRAINT [FK_KnowledgeBaseItem_Users] FOREIGN KEY ([CreatedBy]) REFERENCES [dbo].[Users] ([UserID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[KnowledgeBaseItemHistory]'
GO
ALTER TABLE [dbo].[KnowledgeBaseItemHistory] WITH NOCHECK ADD
CONSTRAINT [FK_KnowledgeBaseItemHistory_Users] FOREIGN KEY ([CreatedBy]) REFERENCES [dbo].[Users] ([UserID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[NamedUser]'
GO
ALTER TABLE [dbo].[NamedUser] WITH NOCHECK ADD
CONSTRAINT [FK_NamedUser_Users] FOREIGN KEY ([UserID]) REFERENCES [dbo].[Users] ([UserID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[Read_IncidentUser]'
GO
ALTER TABLE [dbo].[Read_IncidentUser] WITH NOCHECK ADD
CONSTRAINT [FK_ReadIncidentUser_Users] FOREIGN KEY ([UserID]) REFERENCES [dbo].[Users] ([UserID]) ON DELETE CASCADE
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[ReceivedEmail]'
GO
ALTER TABLE [dbo].[ReceivedEmail] WITH NOCHECK ADD
CONSTRAINT [FK_ReceivedEmail_Email] FOREIGN KEY ([MessageID]) REFERENCES [dbo].[Email] ([MessageID]),
CONSTRAINT [FK_ReceivedEmail_Users] FOREIGN KEY ([ServiceUserID]) REFERENCES [dbo].[Users] ([UserID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[TaggedIncidents]'
GO
ALTER TABLE [dbo].[TaggedIncidents] WITH NOCHECK ADD
CONSTRAINT [FK_TaggedIncidents_Users] FOREIGN KEY ([UserID]) REFERENCES [dbo].[Users] ([UserID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[User_BusinessUnit]'
GO
ALTER TABLE [dbo].[User_BusinessUnit] WITH NOCHECK ADD
CONSTRAINT [FK_User_BusinessUnit_Users] FOREIGN KEY ([UserID]) REFERENCES [dbo].[Users] ([UserID]) ON DELETE CASCADE
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[User_Group]'
GO
ALTER TABLE [dbo].[User_Group] WITH NOCHECK ADD
CONSTRAINT [FK_Groups_Users_Users] FOREIGN KEY ([UserID]) REFERENCES [dbo].[Users] ([UserID]) ON DELETE CASCADE
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[User_Role]'
GO
ALTER TABLE [dbo].[User_Role] WITH NOCHECK ADD
CONSTRAINT [FK_User_Role_Users] FOREIGN KEY ([UserID]) REFERENCES [dbo].[Users] ([UserID]) ON DELETE CASCADE
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[UserLoginLog]'
GO
ALTER TABLE [dbo].[UserLoginLog] WITH NOCHECK ADD
CONSTRAINT [FK_UserLoginLog_Users] FOREIGN KEY ([UserID]) REFERENCES [dbo].[Users] ([UserID]) ON DELETE CASCADE
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[UserPreference]'
GO
ALTER TABLE [dbo].[UserPreference] WITH NOCHECK ADD
CONSTRAINT [FK_UserPreference_Users] FOREIGN KEY ([UserID]) REFERENCES [dbo].[Users] ([UserID]) ON DELETE CASCADE
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[KnowledgeBaseItemRating]'
GO
ALTER TABLE [dbo].[KnowledgeBaseItemRating] WITH NOCHECK ADD
CONSTRAINT [FK_KnowledgeBaseItemRating_Users] FOREIGN KEY ([CreatedBy]) REFERENCES [dbo].[Users] ([UserID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[Service]'
GO
ALTER TABLE [dbo].[Service] WITH NOCHECK ADD
CONSTRAINT [FK_Service_Users] FOREIGN KEY ([ServiceManagerID]) REFERENCES [dbo].[Users] ([UserID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[WorkOrderHistory]'
GO
ALTER TABLE [dbo].[WorkOrderHistory] WITH NOCHECK ADD
CONSTRAINT [FK_WorkOrderHistory_Users] FOREIGN KEY ([CreatedBy]) REFERENCES [dbo].[Users] ([UserID]),
CONSTRAINT [FK_WorkOrderHistory_Users1] FOREIGN KEY ([AssigneeID]) REFERENCES [dbo].[Users] ([UserID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[Users]'
GO
ALTER TABLE [dbo].[Users] WITH NOCHECK ADD
CONSTRAINT [FK_Users_CountryRegion] FOREIGN KEY ([CountryRegionID]) REFERENCES [dbo].[CountryRegion] ([CountryRegionID]),
CONSTRAINT [FK_Users_PasswordFormat] FOREIGN KEY ([PasswordFormatID]) REFERENCES [dbo].[PasswordFormat] ([PasswordFormatID]),
CONSTRAINT [FK_Users_Languages] FOREIGN KEY ([LanguageID]) REFERENCES [dbo].[Languages] ([LanguageID]),
CONSTRAINT [FK_Users_UserTemplate] FOREIGN KEY ([UserTemplateID]) REFERENCES [dbo].[UserTemplate] ([UserTemplateID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[UserTemplate]'
GO
ALTER TABLE [dbo].[UserTemplate] WITH NOCHECK ADD
CONSTRAINT [FK_UserTemplate_CountryRegion] FOREIGN KEY ([CountryRegionID]) REFERENCES [dbo].[CountryRegion] ([CountryRegionID]),
CONSTRAINT [FK_UserTemplate_Languages] FOREIGN KEY ([LanguageID]) REFERENCES [dbo].[Languages] ([LanguageID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[IncidentTemplate]'
GO
ALTER TABLE [dbo].[IncidentTemplate] ADD
CONSTRAINT [FK_IncidentTemplate_BusinessUnit] FOREIGN KEY ([BusinessUnitID]) REFERENCES [dbo].[BusinessUnit] ([BusinessUnitID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[SLA_BusinessUnit]'
GO
ALTER TABLE [dbo].[SLA_BusinessUnit] ADD
CONSTRAINT [FK_SLA_BusinessUnit_BusinessUnit] FOREIGN KEY ([BusinessUnitID]) REFERENCES [dbo].[BusinessUnit] ([BusinessUnitID]) ON DELETE CASCADE
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[User_BusinessUnit]'
GO
ALTER TABLE [dbo].[User_BusinessUnit] ADD
CONSTRAINT [FK_User_BusinessUnit_BusinessUnit] FOREIGN KEY ([BusinessUnitID]) REFERENCES [dbo].[BusinessUnit] ([BusinessUnitID]) ON DELETE CASCADE
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[UserTemplate_BusinessUnit]'
GO
ALTER TABLE [dbo].[UserTemplate_BusinessUnit] ADD
CONSTRAINT [FK_UserTemplate_BusinessUnit_BusinessUnit] FOREIGN KEY ([BusinessUnitID]) REFERENCES [dbo].[BusinessUnit] ([BusinessUnitID]) ON DELETE CASCADE,
CONSTRAINT [FK_UserTemplate_BusinessUnit_UserTemplate] FOREIGN KEY ([UserTemplateID]) REFERENCES [dbo].[UserTemplate] ([UserTemplateID]) ON DELETE CASCADE
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[ChatMessages]'
GO
ALTER TABLE [dbo].[ChatMessages] ADD
CONSTRAINT [FK_ChatMessages_Chats] FOREIGN KEY ([ChatID]) REFERENCES [dbo].[Chats] ([ChatID]),
CONSTRAINT [FK_ChatMessages_Users] FOREIGN KEY ([UserID]) REFERENCES [dbo].[Users] ([UserID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[TaggedChats]'
GO
ALTER TABLE [dbo].[TaggedChats] ADD
CONSTRAINT [FK_TaggedChats_Chats] FOREIGN KEY ([ChatID]) REFERENCES [dbo].[Chats] ([ChatID]),
CONSTRAINT [FK_TaggedChats_Users] FOREIGN KEY ([UserID]) REFERENCES [dbo].[Users] ([UserID]),
CONSTRAINT [FK_TaggedChats_Tags] FOREIGN KEY ([TagID]) REFERENCES [dbo].[Tags] ([TagID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[IncidentHistory]'
GO
ALTER TABLE [dbo].[IncidentHistory] ADD
CONSTRAINT [FK_IncidentHistory_ConfigurationItem] FOREIGN KEY ([ConfigurationItemID]) REFERENCES [dbo].[ConfigurationItem] ([ConfigurationItemID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[ConfigurationItem]'
GO
ALTER TABLE [dbo].[ConfigurationItem] ADD
CONSTRAINT [FK_ConfigurationItem_ConfigurationItemTemplate] FOREIGN KEY ([ConfigurationItemTemplateID]) REFERENCES [dbo].[ConfigurationItemTemplate] ([ConfigurationItemTemplateID]),
CONSTRAINT [FK_ConfigurationItem_ConfigurationItemCategory] FOREIGN KEY ([ConfigurationItemCategoryID]) REFERENCES [dbo].[ConfigurationItemCategory] ([ConfigurationItemCategoryID]) ON DELETE CASCADE
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[Incident]'
GO
ALTER TABLE [dbo].[Incident] ADD
CONSTRAINT [FK_Incident_Service] FOREIGN KEY ([ServiceID]) REFERENCES [dbo].[Service] ([ServiceID]),
CONSTRAINT [FK_Incident_IncidentTemplate] FOREIGN KEY ([IncidentTemplateID]) REFERENCES [dbo].[IncidentTemplate] ([IncidentTemplateID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[Languages]'
GO
ALTER TABLE [dbo].[Languages] ADD
CONSTRAINT [FK_Languages_LanguageType] FOREIGN KEY ([LanguageTypeID]) REFERENCES [dbo].[LanguageType] ([LanguageTypeID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[License]'
GO
ALTER TABLE [dbo].[License] ADD
CONSTRAINT [FK_License_ApplicationType] FOREIGN KEY ([ApplicationTypeID]) REFERENCES [dbo].[ApplicationType] ([ApplicationTypeID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[NamedUser]'
GO
ALTER TABLE [dbo].[NamedUser] ADD
CONSTRAINT [FK_NamedUser_License] FOREIGN KEY ([LicenseID]) REFERENCES [dbo].[License] ([LicenseID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[Role_UserTemplate]'
GO
ALTER TABLE [dbo].[Role_UserTemplate] ADD
CONSTRAINT [FK_Role_UserTemplate_UserTemplate] FOREIGN KEY ([UserTemplateID]) REFERENCES [dbo].[UserTemplate] ([UserTemplateID]) ON DELETE CASCADE,
CONSTRAINT [FK_Role_UserTemplate_Role] FOREIGN KEY ([RoleID]) REFERENCES [dbo].[Role] ([RoleID]) ON DELETE CASCADE
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[TaggedIncidents]'
GO
ALTER TABLE [dbo].[TaggedIncidents] ADD
CONSTRAINT [FK_TaggedIncidents_Incident] FOREIGN KEY ([IncidentID]) REFERENCES [dbo].[Incident] ([IncidentID]) ON DELETE CASCADE,
CONSTRAINT [FK_TaggedIncidents_Tags] FOREIGN KEY ([TagID]) REFERENCES [dbo].[Tags] ([TagID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[TaggedUsers]'
GO
ALTER TABLE [dbo].[TaggedUsers] ADD
CONSTRAINT [FK_TaggedUsers_Users] FOREIGN KEY ([UserID]) REFERENCES [dbo].[Users] ([UserID]),
CONSTRAINT [FK_TaggedUsers_Users1] FOREIGN KEY ([TaggedUserEntityID]) REFERENCES [dbo].[Users] ([UserID]),
CONSTRAINT [FK_TaggedUsers_Tags] FOREIGN KEY ([TagID]) REFERENCES [dbo].[Tags] ([TagID])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[UserTemplate_Group]'
GO
ALTER TABLE [dbo].[UserTemplate_Group] ADD
CONSTRAINT [FK_UserTemplate_Group_UserTemplate] FOREIGN KEY ([UserTemplateID]) REFERENCES [dbo].[UserTemplate] ([UserTemplateID]) ON DELETE CASCADE,
CONSTRAINT [FK_UserTemplate_Group_Groups] FOREIGN KEY ([GroupID]) REFERENCES [dbo].[Groups] ([GroupID]) ON DELETE CASCADE
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Adding foreign keys to [dbo].[UserTemplate_Role]'
GO
ALTER TABLE [dbo].[UserTemplate_Role] ADD
CONSTRAINT [FK_UserTemplate_Role_UserTemplate] FOREIGN KEY ([UserTemplateID]) REFERENCES [dbo].[UserTemplate] ([UserTemplateID]) ON DELETE CASCADE,
CONSTRAINT [FK_UserTemplate_Role_Role] FOREIGN KEY ([RoleID]) REFERENCES [dbo].[Role] ([RoleID]) ON DELETE CASCADE
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Disabling constraints on [dbo].[BusinessUnit]'
GO
ALTER TABLE [dbo].[BusinessUnit] NOCHECK CONSTRAINT
[FK_BusinessUnit_BusinessUnit],
[FK_BusinessUnit_CountryRegion],
[FK_BusinessUnit_Languages],
[FK_BusinessUnit_BusinessUnitTemplate]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Disabling constraints on [dbo].[BusinessUnitTemplate]'
GO
ALTER TABLE [dbo].[BusinessUnitTemplate] NOCHECK CONSTRAINT
[FK_BusinessUnitTemplate_BusinessUnit],
[FK_BusinessUnitTemplate_CountryRegion],
[FK_BusinessUnitTemplate_Languages]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Disabling constraints on [dbo].[Incident]'
GO
ALTER TABLE [dbo].[Incident] NOCHECK CONSTRAINT
[FK_Incident_BusinessUnit],
[FK_Incident_ConfigurationItem]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Disabling constraints on [dbo].[IncidentHistory]'
GO
ALTER TABLE [dbo].[IncidentHistory] NOCHECK CONSTRAINT
[FK_IncidentHistory_BusinessUnit],
[FK_IncidentHistory_UsersAssignee]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Disabling constraints on [dbo].[WorkOrder]'
GO
ALTER TABLE [dbo].[WorkOrder] NOCHECK CONSTRAINT
[FK_WorkOrder_BusinessUnit],
[FK_WorkOrder_ConfigurationItem],
[FK_WorkOrder_Users],
[FK_WorkOrder_Users2]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Disabling constraints on [dbo].[WorkOrderTemplate]'
GO
ALTER TABLE [dbo].[WorkOrderTemplate] NOCHECK CONSTRAINT
[FK_WorkOrderTemplate_BusinessUnit],
[FK_WorkOrderTemplate_ConfigurationItem],
[FK_WorkOrderTemplate_Users],
[FK_WorkOrderTemplate_Users1],
[FK_WorkOrderTemplate_WorkOrder]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Disabling constraints on [dbo].[IncidentTemplate]'
GO
ALTER TABLE [dbo].[IncidentTemplate] NOCHECK CONSTRAINT
[FK_IncidentTemplate_ConfigurationItem],
[FK_IncidentTemplate_Users],
[FK_IncidentTemplate_Users1]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Disabling constraints on [dbo].[ConfigurationItemCategory]'
GO
ALTER TABLE [dbo].[ConfigurationItemCategory] NOCHECK CONSTRAINT
[FK_ConfigurationItemCategory_ConfigurationItemCategory]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Disabling constraints on [dbo].[ConfigurationItemTemplate]'
GO
ALTER TABLE [dbo].[ConfigurationItemTemplate] NOCHECK CONSTRAINT
[FK_ConfigurationItemTemplate_ConfigurationItemCategory]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Disabling constraints on [dbo].[ReceivedEmail]'
GO
ALTER TABLE [dbo].[ReceivedEmail] NOCHECK CONSTRAINT
[FK_ReceivedEmail_Email],
[FK_ReceivedEmail_Users]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Disabling constraints on [dbo].[KnowledgeBaseItemRating]'
GO
ALTER TABLE [dbo].[KnowledgeBaseItemRating] NOCHECK CONSTRAINT
[FK_KnowledgeBaseItemRating_Users]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Disabling constraints on [dbo].[Service]'
GO
ALTER TABLE [dbo].[Service] NOCHECK CONSTRAINT
[FK_Service_Users]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Disabling constraints on [dbo].[WorkOrderHistory]'
GO
ALTER TABLE [dbo].[WorkOrderHistory] NOCHECK CONSTRAINT
[FK_WorkOrderHistory_Users1]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Disabling constraints on [dbo].[Users]'
GO
ALTER TABLE [dbo].[Users] NOCHECK CONSTRAINT
[FK_Users_CountryRegion],
[FK_Users_Languages],
[FK_Users_UserTemplate]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Disabling constraints on [dbo].[UserTemplate]'
GO
ALTER TABLE [dbo].[UserTemplate] NOCHECK CONSTRAINT
[FK_UserTemplate_CountryRegion],
[FK_UserTemplate_Languages]
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Altering permissions on [dbo].[sp_show_huge_tables]'
GO
GRANT EXECUTE ON  [dbo].[sp_show_huge_tables] TO [public]
GO
IF EXISTS (SELECT * FROM #tmpErrors) ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT>0 BEGIN
PRINT 'The database update succeeded'
COMMIT TRANSACTION
END
ELSE PRINT 'The database update failed'
GO
DROP TABLE #tmpErrors
GO
PRINT N'Creating full text catalogs'
GO
CREATE FULLTEXT CATALOG [FullTextCatalog]
ON FILEGROUP [PRIMARY]
--IN PATH 'c:\Microsoft SQL Server\MSSQL.1\MSSQL\FTData'
WITH ACCENT_SENSITIVITY = ON
AUTHORIZATION [dbo]
GO
PRINT N'Adding full text indexing to tables'
GO
CREATE FULLTEXT INDEX ON [dbo].[ChatMessages] KEY INDEX [PK_ChatMessages] ON [FullTextCatalog]
GO
CREATE FULLTEXT INDEX ON [dbo].[IncidentHistory] KEY INDEX [PK_IncidentHistory] ON [FullTextCatalog]
GO
PRINT N'Adding full text indexing to columns'
GO
ALTER FULLTEXT INDEX ON [dbo].[ChatMessages] ADD (MessageBody LANGUAGE 1033)
GO
ALTER FULLTEXT INDEX ON [dbo].[IncidentHistory] ADD (Title LANGUAGE 1033)
GO
ALTER FULLTEXT INDEX ON [dbo].[IncidentHistory] ADD (Resolution LANGUAGE 1033)
GO
ALTER FULLTEXT INDEX ON [dbo].[IncidentHistory] ADD (Description LANGUAGE 1033)
GO
ALTER FULLTEXT INDEX ON [dbo].[ChatMessages] ENABLE
GO
ALTER FULLTEXT INDEX ON [dbo].[IncidentHistory] ENABLE
GO


























/* Update Roles */
UPDATE Role SET RoleType = 'ServiceUserRole';

UPDATE Role SET RoleType = 'AdministratorUserRole' WHERE RoleID = 1;
UPDATE Role SET RoleType = 'AdministratorUserRole' WHERE RoleID = 2;
UPDATE Role SET RoleType = 'SupportRepresentativeRole' WHERE RoleID = 3;

/* Update Incident Templates */
UPDATE IncidentTemplate SET ImpactID = NULL WHERE ImpactID = 0;
UPDATE IncidentTemplate SET UrgencyID = NULL WHERE UrgencyID = 0;
UPDATE IncidentTemplate SET PriorityID = NULL WHERE PriorityID = 0;
UPDATE IncidentTemplate SET AssigneeID = NULL WHERE AssigneeID = 0;
UPDATE IncidentTemplate SET ClosureClassificationID = NULL WHERE ClosureClassificationID = 0;
UPDATE IncidentTemplate SET IncidentCategoryID = NULL WHERE IncidentCategoryID = 0;
UPDATE IncidentTemplate SET IncidentOriginID = NULL WHERE IncidentOriginID = 0;
UPDATE IncidentTemplate SET ServiceUserID = NULL WHERE ServiceUserID = 0;
UPDATE IncidentTemplate SET BusinessUnitID = NULL WHERE BusinessUnitID = 0;
UPDATE IncidentTemplate SET ServiceID = NULL WHERE ServiceID = 0;

/* Update Groups */
UPDATE Groups SET GroupType = 'RegularGroup';

UPDATE Groups SET GroupType = 'AllUsersGroup' WHERE GroupID = 1;
UPDATE Groups SET GroupType = 'SystemUsersGroup' WHERE GroupID = 2;
UPDATE Groups SET GroupType = 'AdministratorsGroup' WHERE GroupID = 3;

/* Update Users */
UPDATE Users SET LanguageID = NULL;
UPDATE Users SET UserType = 'RegularUser';

UPDATE Users SET UserType = 'SystemUser' WHERE UserID = 1;
UPDATE Users SET UserType = 'Administrator' WHERE UserID = 2;

/* Add anonymous user */
INSERT INTO Users (FirstName, LastName, Email, Password, UserName, LanguageID, UserType) VALUES ('Anonymous', 'User', 'anonymous@anonymous', '5BAA61E4C9B93F3F0682250B6CF8331B7EE68FD8', 'anonymous', NULL, 'AnonymousUser')

/*DECLARE @UserID bigint
SET @UserID = (SELECT UserID FROM Users WHERE UserName='anonymous')

INSERT INTO User_Group (GroupID, UserID) SELECT grp.GroupID, usr.UserID FROM Groups grp LEFT OUTER JOIN Users usr ON UserID=@UserID
INSERT INTO User_Role (RoleID, UserID) VALUES (4, @UserID);*/

/* Update Options */
INSERT INTO Options (OptionName, OptionValue) VALUES ('EmailDefaultAssigneeGroup', '4');
INSERT INTO Options (OptionName, OptionValue) VALUES ('EmailDefaultIncidentTemplate', '1');
INSERT INTO Options (OptionName, OptionValue) VALUES ('IncidentPriorityEscalationTime', '0');
INSERT INTO Options (OptionName, OptionValue) VALUES ('EnableIncidentPriorityEscalation', 'false');

UPDATE Options SET OptionValue = '13' WHERE OptionID = 1;
UPDATE Options SET OptionValue = '9' WHERE OptionID = 2;
UPDATE Options SET OptionValue = '11' WHERE OptionID = 3;
UPDATE Options SET OptionValue = '800' WHERE OptionID = 4;
UPDATE Options SET OptionValue = '600' WHERE OptionID = 5;
UPDATE Options SET OptionValue = '480' WHERE OptionID = 6;
UPDATE Options SET OptionValue = '540' WHERE OptionID = 7;
UPDATE Options SET OptionValue = 'true' WHERE OptionID = 8;
UPDATE Options SET OptionValue = '0' WHERE OptionID = 26;
UPDATE Options SET OptionValue = '40' WHERE OptionID = 33;
UPDATE Options SET OptionValue = '4' WHERE OptionID = 42;
UPDATE Options SET OptionValue = '5' WHERE OptionID = 43;
UPDATE Options SET OptionValue = '4' WHERE OptionID = 44;
UPDATE Options SET OptionValue = '1' WHERE OptionID = 45;
UPDATE Options SET OptionValue = '' WHERE OptionID = 46;
UPDATE Options SET OptionValue =  '' WHERE OptionID = 47;
UPDATE Options SET OptionValue = 'false' WHERE OptionID = 48;
UPDATE Options SET OptionValue = '0' WHERE OptionID = 49;
UPDATE Options SET OptionValue = 'false' WHERE OptionID = 50;

/* Update Incident Template */
UPDATE IncidentTemplate SET IncidentTemplateType = 'DefaultIncidentTemplate';

/* Update Configuration Item Template */
UPDATE ConfigurationItemTemplate SET ConfigurationItemTemplateType = 'DefaultConfigurationItemTemplate';

/* Update Business Unit */
UPDATE BusinessUnit SET BusinessUnitType = 'DefaultBusinessUnit';
UPDATE BusinessUnit SET LanguageID = NULL;







/************************************************************/
/*****               UserTmeplate        	        *****/
/************************************************************/

INSERT INTO [dbo].[UserTemplate] (UserTemplateName, ReceiveEmails) VALUES ('Default User Template', 1)


/************************************************************/
/*****                    Items                        *****/
/************************************************************/

INSERT INTO [dbo].[Item]([ItemName], [AllowCreate], [AllowRead], [AllowUpdate], [AllowDelete], [ParentItemID]) VALUES('Configuration Item', 0, 1, 1, 1, 7)

/************************************************************/
/*****                   UserToNotify                   *****/
/************************************************************/

INSERT INTO [dbo].[UserToNotify] ([UserToNotifyName]) VALUES ('Advanced Service Users')

/* Users */
UPDATE Users SET FirstName = 'Guest' WHERE Username = 'anonymous';

/* Options */
INSERT INTO Options(OptionName, OptionValue) VALUES ('HelpDeskTitle', 'Welcome to Polar Help Desk');
INSERT INTO Options(OptionName, OptionValue) VALUES ('GmtZoneIndex', '0');

UPDATE Options SET OptionValue = 'Welcome to Polar Help Desk' WHERE OptionID = 52;
UPDATE Options SET OptionValue = '0' WHERE OptionID = 53;


/************************************************************/
/*****               Widgets		                *****/
/************************************************************/

INSERT INTO [dbo].Widgets (Name, Value) VALUES ('LeftMenu', '')

INSERT INTO [dbo].Widgets (Name, Value) VALUES ('Bottom', '')

INSERT INTO [dbo].Widgets (Name, Value) VALUES ('InicidentPopup', '')


/************************************************************/
/*****                  DatabaseVersion		        *****/
/************************************************************/

UPDATE [dbo].[DatabaseVersion] SET [VersionNumber]='5.0.10.0'
